(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4800,        163]*)
(*NotebookOutlinePosition[      5807,        198]*)
(*  CellTagsIndexPosition[      5733,        192]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["BaseIndexQ", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["BaseIndexQ",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox["index",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "returns True if index has a base index value as its raw index and False \
otherwise."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{
        RowBox[{"{", 
          RowBox[{"i", ",", 
            RowBox[{"red", "[", "i", "]"}], ",", 
            RowBox[{"rocket", "[", "i", "]"}], ",", 
            RowBox[{"Cov", "[", "i", "]"}], ",", 
            RowBox[{"Cov", "[", 
              RowBox[{"red", "[", "i", "]"}]}]}]}], "}"}]]],
  " all have the raw index i."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["BaseIndices",
    ButtonData:>{"BaseIndices"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NDim",
    ButtonData:>{"NDim"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeclareBaseIndices",
    ButtonData:>{"DeclareBaseIndices"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["This sets the linear space and index flavors.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[Range[3]]\), "\n", 
    \(\(IndexFlavors = {};\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {blue, Blue}, {rocket, 
            OverTilde}};\)\), "\n", 
    \({NDim, BaseIndices}\)}], "Input",
  CellLabel->"In[5]:="],

Cell["These should all be True...", "Text"],

Cell[BoxData[{
    \({1, 2, 3, red[1], red[2], red[3], blue[1], blue[2], blue[3], rocket[1], 
      rocket[2], rocket[3], Cov[1], Cov[red[1]], Dif[rocket[1]], Cov[1], 
      Cov[red[1]], Cov[rocket[1]]}\), "\[IndentingNewLine]", 
    \(BaseIndexQ /@ %\)}], "Input",
  CellLabel->"In[9]:="],

Cell["These should all be False...", "Text"],

Cell[BoxData[{
    \({4, red[4], blue[4], rocket[4], Cov[4], Cov[red@4], Cov[i], Cov[red@i], 
      i, j, k}\), "\[IndentingNewLine]", 
    \(BaseIndexQ /@ %\)}], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
The following gives a warning message because green is not a current \
flavor.\
\>", "Text"],

Cell[BoxData[
    \(BaseIndexQ[green@1]\)], "Input",
  CellLabel->"In[13]:="],

Cell["Restore the initial state.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[14]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 376, 15, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5562, 183}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 376, 15, 32, "Usage",
  CellTags->"Function?"],
Cell[2215, 73, 394, 11, 31, "MathCaption"],
Cell[2612, 86, 348, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2985, 104, 36, 0, 40, "ExampleSection"],
Cell[3024, 106, 96, 2, 29, "Input"],
Cell[3123, 110, 187, 4, 69, "Input"],
Cell[3313, 116, 61, 0, 25, "Text"],
Cell[3377, 118, 283, 6, 89, "Input"],
Cell[3663, 126, 43, 0, 25, "Text"],
Cell[3709, 128, 289, 5, 89, "Input"],
Cell[4001, 135, 44, 0, 25, "Text"],
Cell[4048, 137, 196, 4, 49, "Input"],
Cell[4247, 143, 102, 3, 25, "Text"],
Cell[4352, 148, 77, 2, 29, "Input"],
Cell[4432, 152, 42, 0, 25, "Text"],
Cell[4477, 154, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

