(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4058,        152]*)
(*NotebookOutlinePosition[      5043,        186]*)
(*  CellTagsIndexPosition[      4969,        180]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["BaseIndices", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData["BaseIndices"]],
  " gives the current set of base indices for the underlying linear space."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "BaseIndices are set by ",
  Cell[BoxData[
      \(DeclareBaseIndices\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "The length of ",
  Cell[BoxData[
      \(BaseIndices\)]],
  " determines ",
  Cell[BoxData[
      \(NDim\)]],
  ", the dimension of the underlying linear space."
}], "MathCaption"],

Cell[TextData[{
  "Base indices may be integers or symbols. You could use ",
  Cell[BoxData[
      \({0, 1, 2, 3}\)]],
  " for relativity, or ",
  Cell[BoxData[
      \({t, x, y, z}\)]],
  ", or ",
  Cell[BoxData[
      \({\[Rho], \[Theta], \[Phi]}\)]],
  " for a spherical coordinate system."
}], "MathCaption"],

Cell[TextData[{
  "On loading, Tensorial automatically initializes the base indices to ",
  Cell[BoxData[
      \({1, 2, 3}\)]],
  "."
}], "MathCaption"],

Cell["\<\
Base indices are not in themselves flavored, but flavors may be added to \
them.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DeclareBaseIndices",
    ButtonData:>{"DeclareBaseIndices"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NDim",
    ButtonData:>{"NDim"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["BaseIndexQ",
    ButtonData:>{"BaseIndexQ"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["The following gives the current set of base indices...", "Text"],

Cell[BoxData[
    \(oldindices = BaseIndices\)], "Input",
  CellLabel->"In[2]:="],

Cell["The base indices can be changed with", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{t, x, y, z}]\), "\[IndentingNewLine]", 
    \(BaseIndices\)}], "Input",
  CellLabel->"In[3]:="],

Cell["This resets to the old indices.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(BaseIndices\), "\[IndentingNewLine]", 
    \(Clear[oldindices]\)}], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 188, 5, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 4799, 171}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 188, 5, 32, "Usage",
  CellTags->"Function?"],
Cell[2028, 63, 117, 5, 31, "MathCaption"],
Cell[2148, 70, 199, 8, 31, "MathCaption"],
Cell[2350, 80, 312, 11, 48, "MathCaption"],
Cell[2665, 93, 153, 5, 31, "MathCaption"],
Cell[2821, 100, 111, 3, 31, "MathCaption"],
Cell[2935, 105, 346, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3306, 123, 36, 0, 40, "ExampleSection"],
Cell[3345, 125, 96, 2, 29, "Input"],
Cell[3444, 129, 70, 0, 25, "Text"],
Cell[3517, 131, 81, 2, 29, "Input"],
Cell[3601, 135, 52, 0, 25, "Text"],
Cell[3656, 137, 136, 3, 49, "Input"],
Cell[3795, 142, 47, 0, 25, "Text"],
Cell[3845, 144, 185, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

