(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4545,        160]*)
(*NotebookOutlinePosition[      5533,        194]*)
(*  CellTagsIndexPosition[      5459,        188]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ContractArray", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["ContractArray",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(tarray, \ {lev1, lev2} ... \),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will contract the indicated pairs of level numbers in the tensor array \
tarray"
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 The purpose of ContractArray is to perform contractions on the full matrix \
or array forms of tensors.  Generally it is preferable to use tensor methods.\
\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SumExpansion",
    ButtonData:>{"SumExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToArrayValues",
    ButtonData:>{"ToArrayValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrayExpansion",
    ButtonData:>{"ArrayExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EinsteinSum",
    ButtonData:>{"EinsteinSum"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell["See also the second Example, Arrays & Tensors.", "Text"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the old settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(DeclareBaseIndices[{1, 2, 3}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[T, 3]\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
The normal way to contract a tensor is to repeat an index in an up and down \
position. The following contracts the first and third slots of the tensor \
T.\
\>", "Text"],

Cell[BoxData[{
    \(Tuud[i, j, i]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "Sometimes, you may wish to contract an array after it has been expanded to \
a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " array. ContractArray can then be used. It is not as efficient because we \
had to generate all the extra terms that were subsequently thrown away."
}], "Text"],

Cell[BoxData[{
    \(Tuud[i, j, k]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(ContractArray[%, {1, 3}]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[T, 3]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(Clear[oldindices]\)}], "Input",
  CellLabel->"In[12]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{674, 474},
WindowMargins->{{-2, Automatic}, {Automatic, -2}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 399, 15, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5288, 179}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 399, 15, 32, "Usage",
  CellTags->"Function?"],
Cell[2241, 73, 188, 4, 48, "MathCaption"],
Cell[2432, 79, 460, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2917, 101, 34, 0, 40, "ExampleSection"],
Cell[2954, 103, 62, 0, 25, "Text"],
Cell[3019, 105, 96, 2, 29, "Input"],
Cell[3118, 109, 38, 0, 25, "Text"],
Cell[3159, 111, 134, 3, 49, "Input"],
Cell[3296, 116, 84, 2, 29, "Input"],
Cell[3383, 120, 180, 4, 42, "Text"],
Cell[3566, 126, 178, 4, 69, "Input"],
Cell[3747, 132, 316, 7, 42, "Text"],
Cell[4066, 141, 184, 4, 69, "Input"],
Cell[4253, 147, 33, 0, 25, "Text"],
Cell[4289, 149, 84, 2, 29, "Input"],
Cell[4376, 153, 141, 3, 49, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

