(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6917,        255]*)
(*NotebookOutlinePosition[      7924,        290]*)
(*  CellTagsIndexPosition[      7850,        284]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CovariantD", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["CovariantD",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(expr, i\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents the covariant derivative of the tensor expression with respect \
to the index ",
  Cell[BoxData[
      \(i\)]],
  ".\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["CovariantD",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(expr, {i, j,  ... }\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents the covariant derivative of the expression with respect to the \
list of indices."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " Covariant derivatives are left in index form, with each covariant index \
wrapped in a ",
  Cell[BoxData[
      \(Cov\)]],
  " header, until ",
  Cell[BoxData[
      \(ExpandCovariantD\)]],
  " is used."
}], "MathCaption"],

Cell[TextData[{
  " Each covariant index is prefixed by a semi-colon in the output display. \
The format can be changed using ",
  Cell[BoxData[
      \(SetDerivativeSymbols\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "The intended flavors must be on the indices in ",
  Cell[BoxData[
      \(CovariantD\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExpandCovariantD",
    ButtonData:>{"ExpandCovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AbsoluteD",
    ButtonData:>{"AbsoluteD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetDerivativeSymbols",
    ButtonData:>{"SetDerivativeSymbols"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tensor",
    ButtonData:>{"Tensor"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{S, T}, 1}, {{S, T}, 2}]\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "Here is a tensor T and its covariant derivative with respect to index k. \
In the FullForm we see that the covariant index is simply wrapped in the \
header ",
  Cell[BoxData["Cov"]],
  ". In the display it is prefixed with a semi-colon."
}], "Text"],

Cell[BoxData[{
    \(Td[i]\), "\[IndentingNewLine]", 
    \(CovariantD[%, k]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
Since this is a single tensor label, it could also be entered this way.\
\>", "Text"],

Cell[BoxData[
    \(Tdd[i, Cov[k]]\)], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
Normal linear and Liebnizian differentiation rules are applied.\
\>", "Text"],

Cell[BoxData[{
    \({Su[i] + Tu[i], Su[i] Tu[j]}\), "\[IndentingNewLine]", 
    \(\(CovariantD[#, k] &\) /@ %\)}], "Input",
  CellLabel->"In[11]:="],

Cell["Symbols and numeric quantities are not differentiated.", "Text"],

Cell[BoxData[{
    \(2\ \[Pi]\ a\ Su[i] Tu[j]\), "\[IndentingNewLine]", 
    \(CovariantD[%, k]\)}], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
The flavor must be on the covariant index when differentiating flavored \
expressions.\
\>", "Text"],

Cell[BoxData[{
    \(\(2\ \[Pi]\ a\)\/\(1 + \[Nu]\)\ Su[i] Tu[j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(CovariantD[%, red@k]\)}], "Input",
  CellLabel->"In[15]:="],

Cell["\<\
Higher order derivatives can be performed with a semi-color on each \
differentiated index.\
\>", "Text"],

Cell[BoxData[
    \(CovariantD[Su[i] Tu[j], {m, n}]\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
Covariant derivatives of scalar tensors have a partial differentiation for \
the first index.\
\>", "Text"],

Cell[BoxData[{
    \(Tensor[\[Phi]]\), "\[IndentingNewLine]", 
    \(CovariantD[%, i]\), "\[IndentingNewLine]", 
    \(CovariantD[%, j]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{S, T}, 1}, {{S, T}, 2}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[{
    \(\(DeclareBaseIndices[oldindices];\)\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[oldflavors];\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  "See ",
  ButtonBox["ExpandCovariantD",
    ButtonData:>{"ExpandCovariantD"},
    ButtonStyle->"AddOnsLink"],
  " for more examples."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 769, 30, 55, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7679, 275}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 769, 30, 55, "Usage",
  CellTags->"Function?"],
Cell[2608, 88, 242, 9, 48, "MathCaption"],
Cell[2853, 99, 203, 6, 48, "MathCaption"],
Cell[3059, 107, 133, 5, 31, "MathCaption"],
Cell[3195, 114, 646, 26, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3866, 144, 34, 0, 40, "ExampleSection"],
Cell[3903, 146, 96, 2, 29, "Input"],
Cell[4002, 150, 34, 0, 25, "Text"],
Cell[4039, 152, 268, 5, 89, "Input"],
Cell[4310, 159, 104, 2, 29, "Input"],
Cell[4417, 163, 269, 6, 42, "Text"],
Cell[4689, 171, 161, 4, 69, "Input"],
Cell[4853, 177, 95, 2, 25, "Text"],
Cell[4951, 181, 72, 2, 29, "Input"],
Cell[5026, 185, 87, 2, 25, "Text"],
Cell[5116, 189, 149, 3, 49, "Input"],
Cell[5268, 194, 70, 0, 25, "Text"],
Cell[5341, 196, 134, 3, 49, "Input"],
Cell[5478, 201, 110, 3, 25, "Text"],
Cell[5591, 206, 181, 4, 62, "Input"],
Cell[5775, 212, 115, 3, 25, "Text"],
Cell[5893, 217, 89, 2, 29, "Input"],
Cell[5985, 221, 117, 3, 25, "Text"],
Cell[6105, 226, 174, 4, 69, "Input"],
Cell[6282, 232, 33, 0, 25, "Text"],
Cell[6318, 234, 104, 2, 29, "Input"],
Cell[6425, 238, 298, 5, 89, "Input"],
Cell[6726, 245, 163, 6, 25, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

