(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5544,        194]*)
(*NotebookOutlinePosition[      6569,        230]*)
(*  CellTagsIndexPosition[      6495,        224]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DeclareZeroTensor", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DeclareZeroTensor",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox["label",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " declares that a tensor od any type with the given label will have zero \
element values when expanded to an array."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Using a zero tensor allows free indices to balance on both sides of an \
equation.\
\>", "MathCaption"],

Cell["\<\
Tensor shortcuts must still be defined for a zero tensor if you intend to use \
them.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SetTensorValueRules",
    ButtonData:>{"SetTensorValueRules"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetTensorValues",
    ButtonData:>{"SetTensorValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClearTensorValues",
    ButtonData:>{"ClearTensorValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tensor",
    ButtonData:>{"Tensor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseCoordinates",
    ButtonData:>{"UseCoordinates"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings.", "Text"],

Cell[BoxData[
    \(\(oldindices = BaseIndices;\)\)], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[{1, 2}]\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{\[Lambda], 1}]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "Use zero as the label for zero tensors. We could have used any label. (But \
the capital O letter is protected in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".)"
}], "Text"],

Cell[BoxData[
    \(DeclareZeroTensor[zero]\)], "Input",
  CellLabel->"In[5]:="],

Cell["We still have to define shortcuts.", "Text"],

Cell[BoxData[
    \(DefineTensorShortcuts[{zero, 1}, {zero, 2}, {zero, 3}]\)], "Input",
  CellLabel->"In[6]:="],

Cell["Now the following tensors will expand to zero.", "Text"],

Cell[BoxData[{
    \(zerou[a]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[{
    \(zerouu[a, b]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[{
    \(zerouud[a, b, c]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
The equation for parallel transport of a vector is often written in the \
following way in the books. But if we try to expand this to an array of \
equations, Tensorial objects because the free indices do not match.\
\>", "Text"],

Cell[BoxData[{
    \(AbsoluteD[\[Lambda]u[a], \ u] \[Equal] 0\), "\[IndentingNewLine]", 
    \(MapAt[ExpandAbsoluteD[{x, \[Delta], g, \[CapitalGamma]}, {c, d}], %, 
      1]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
Using a zero tensor provides a balanced equation that can be expanded without \
fuss.\
\>", "Text"],

Cell[BoxData[{
    \(AbsoluteD[\[Lambda]u[a], \ u] \[Equal] 
      zerou[a]\), "\[IndentingNewLine]", 
    \(MapAt[ExpandAbsoluteD[{x, \[Delta], g, \[CapitalGamma]}, {c, d}], %, 
      1]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[{
    \(\(DeclareBaseIndices[oldindices];\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices]\)}], "Input",
  CellLabel->"In[19]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 414, 15, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6324, 215}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 414, 15, 49, "Usage",
  CellTags->"Function?"],
Cell[2260, 73, 113, 3, 31, "MathCaption"],
Cell[2376, 78, 116, 3, 31, "MathCaption"],
Cell[2495, 83, 580, 22, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[3100, 109, 34, 0, 40, "ExampleSection"],
Cell[3137, 111, 96, 2, 29, "Input"],
Cell[3236, 115, 34, 0, 25, "Text"],
Cell[3273, 117, 86, 2, 29, "Input"],
Cell[3362, 121, 156, 3, 49, "Input"],
Cell[3521, 126, 206, 6, 25, "Text"],
Cell[3730, 134, 80, 2, 29, "Input"],
Cell[3813, 138, 50, 0, 25, "Text"],
Cell[3866, 140, 111, 2, 29, "Input"],
Cell[3980, 144, 62, 0, 25, "Text"],
Cell[4045, 146, 121, 3, 49, "Input"],
Cell[4169, 151, 125, 3, 49, "Input"],
Cell[4297, 156, 130, 3, 49, "Input"],
Cell[4430, 161, 239, 4, 42, "Text"],
Cell[4672, 167, 283, 5, 69, "Input"],
Cell[4958, 174, 109, 3, 25, "Text"],
Cell[5070, 179, 297, 6, 69, "Input"],
Cell[5370, 187, 146, 3, 49, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

