(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5497,        192]*)
(*NotebookOutlinePosition[      6483,        226]*)
(*  CellTagsIndexPosition[      6409,        220]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DummySimplify", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["DummySimplify",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will attempt to simplify the dummy indices in the tensor expression to \
produce a minimum number of dummy indices."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 IndexChange can be used to perform specific reindexing under the user's \
control\
\>", "MathCaption"],

Cell["\<\
 DummySimplify will perform automatic reindexing in an attempt to simplify \
tensor expressions.\
\>", "MathCaption"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(SimplifyTensorSum\)]],
  " is an alternative routine that sometimes works better."
}], "MathCaption"],

Cell[TextData[{
  " The simplification routines are not high powered. They do not take into \
account symmetries. See ",
  Cell[BoxData[
      \(SymmetrizeSlots\)]],
  " to apply some symmetries."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["EinsteinSum",
    ButtonData:>{"EinsteinSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UpDownSwap",
    ButtonData:>{"UpDownSwap"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IndexChange",
    ButtonData:>{"IndexChange"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SymmetrizeSlots",
    ButtonData:>{"SymmetrizeSlots"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NondependentPartialD",
    ButtonData:>{"NondependentPartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyTensorSum",
    ButtonData:>{"SimplifyTensorSum"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save old settings and declare an index flavor.", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{b, B, G, U}, 1}, {{A, G}, 2}, {a, 3}, {F, 
        4}]\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
DummySimplify will usually perform the desired dummy index simplification in \
expressions.\
\>", "Text"],

Cell[BoxData[{
    \(a\ Auu[i, j] Gd[i] + b\ Auu[k, j] Gd[k]\), "\[IndentingNewLine]", 
    \(% // DummySimplify\), "\[IndentingNewLine]", 
    \(% // Simplify\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[{
    \(a\ Auu[i, j] Bu[k] Gdd[j, k] Ud[i] + 
        b\ Auu[k, m] Bu[p] Gdd[m, p] Ud[k] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(\(% // DummySimplify\) // Simplify\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[{
    \(a\ Fdduu[i, j, i, j] + b\ Fdduu[j, p, j, p] + 
      c\ Fdduu[m, r, m, r]\), "\n", 
    \(\(% // DummySimplify\) // Simplify\)}], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[{
    \(\((addd[r, s, t] + addd[s, r, t] + addd[s, t, r])\) bu[r] bu[s] bu[t] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // DummySimplify\)}], "Input",
  CellLabel->"In[13]:="],

Cell["Restore old settings...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{b, B, G, U}, 1}, {{A, G}, 2}, {a, 3}, {F, 
        4}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[{
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldflavors]\)}], "Input",
  CellLabel->"In[16]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{669, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 33, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 410, 15, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6238, 211}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 33, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 410, 15, 49, "Usage",
  CellTags->"Function?"],
Cell[2252, 73, 113, 3, 31, "MathCaption"],
Cell[2368, 78, 127, 3, 31, "MathCaption"],
Cell[2498, 83, 148, 5, 31, "MathCaption"],
Cell[2649, 90, 215, 6, 48, "MathCaption"],
Cell[2867, 98, 684, 26, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[3576, 128, 34, 0, 40, "ExampleSection"],
Cell[3613, 130, 96, 2, 29, "Input"],
Cell[3712, 134, 62, 0, 25, "Text"],
Cell[3777, 136, 205, 4, 69, "Input"],
Cell[3985, 142, 135, 3, 29, "Input"],
Cell[4123, 147, 115, 3, 25, "Text"],
Cell[4241, 152, 197, 4, 69, "Input"],
Cell[4441, 158, 231, 5, 49, "Input"],
Cell[4675, 165, 184, 4, 49, "Input"],
Cell[4862, 171, 205, 4, 49, "Input"],
Cell[5070, 177, 39, 0, 25, "Text"],
Cell[5112, 179, 135, 3, 29, "Input"],
Cell[5250, 184, 219, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

