(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6573,        224]*)
(*NotebookOutlinePosition[      7559,        258]*)
(*  CellTagsIndexPosition[      7485,        252]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["EinsteinArray", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["EinsteinArray",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[
            RowBox[{"base", ":", "BaseIndices"}],
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  " will form an array on the free indices in the expression. The range of \
the expansion is over the base list, which has the default value of \
BaseIndices."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
The expansion will be done in the natural sort order of the raw free indices \
with the first sorted index at the highest level.\
\>", "MathCaption"],

Cell["\<\
 Flavored indices as well as plain indices are automatically expanded.\
\>", "MathCaption"],

Cell["\<\
No tensor label may be the same as one of the expansion indices, otherwise \
incorrect results will be obtained. If this unlikely case should occur you \
can reindex to avoid the problem.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SumExpansion",
    ButtonData:>{"SumExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EinsteinSum",
    ButtonData:>{"EinsteinSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ArrayExpansion",
    ButtonData:>{"ArrayExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToArrayValues",
    ButtonData:>{"ToArrayValues"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare base indices and flavors.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
            SuperDagger}};\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{x, y}, 1}, {S, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["The following expand vectors into their components...", "Text"],

Cell[BoxData[{
    \(xu[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[{
    \(xu[i] + yu[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[10]:="],

Cell["An expansion can be done over a subset of the BaseIndices.", "Text"],

Cell[BoxData[{
    \(xu[i] + yu[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[{1, 3}]\)}], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
If the free indices do not match in all terms, an error message is issued and \
the operation is aborted.\
\>", "Text"],

Cell[BoxData[{
    \(xu[i] + yu[j]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[14]:="],

Cell["The following expands a second order tensor into an array.", "Text"],

Cell[BoxData[{
    \(Suu[i, j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[16]:="],

Cell[TextData[{
  "The expansion occurs on the sort order of the indices. To obtain other \
expansion orders use ",
  Cell[BoxData["ArrayExpansion"]],
  " or change the indices in the expression. Changing the sort order of the \
indices..."
}], "Text"],

Cell[BoxData[{
    \(Suu[j, i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\)}], "Input",
  CellLabel->"In[18]:="],

Cell[TextData[{
  "Using ",
  Cell[BoxData["ArrayExpansion"]],
  "..."
}], "Text"],

Cell[BoxData[{
    \(Suu[i, j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // ArrayExpansion[red /@ {j, i}]\)}], "Input",
  CellLabel->"In[20]:="],

Cell["The following expands a set of equations.", "Text"],

Cell[BoxData[{
    \(yu[i] \[Equal] Sud[i, j] xu[j] // 
      ToFlavor[rocket]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[22]:="],

Cell["Restore the initial values...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, y}, 1}, {S, 2}]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[26]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 651, 24, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7314, 243}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 651, 24, 49, "Usage",
  CellTags->"Function?"],
Cell[2493, 82, 159, 3, 48, "MathCaption"],
Cell[2655, 87, 101, 2, 31, "MathCaption"],
Cell[2759, 91, 218, 4, 48, "MathCaption"],
Cell[2980, 97, 460, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3465, 119, 34, 0, 40, "ExampleSection"],
Cell[3502, 121, 96, 2, 29, "Input"],
Cell[3601, 125, 71, 0, 25, "Text"],
Cell[3675, 127, 359, 7, 109, "Input"],
Cell[4037, 136, 99, 2, 29, "Input"],
Cell[4139, 140, 69, 0, 25, "Text"],
Cell[4211, 142, 118, 3, 49, "Input"],
Cell[4332, 147, 127, 3, 49, "Input"],
Cell[4462, 152, 74, 0, 25, "Text"],
Cell[4539, 154, 133, 3, 49, "Input"],
Cell[4675, 159, 129, 3, 25, "Text"],
Cell[4807, 164, 127, 3, 49, "Input"],
Cell[4937, 169, 74, 0, 25, "Text"],
Cell[5014, 171, 140, 3, 49, "Input"],
Cell[5157, 176, 252, 6, 42, "Text"],
Cell[5412, 184, 140, 3, 49, "Input"],
Cell[5555, 189, 82, 4, 25, "Text"],
Cell[5640, 195, 154, 3, 49, "Input"],
Cell[5797, 200, 57, 0, 25, "Text"],
Cell[5857, 202, 240, 5, 69, "Input"],
Cell[6100, 209, 45, 0, 25, "Text"],
Cell[6148, 211, 99, 2, 29, "Input"],
Cell[6250, 215, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

