(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6768,        228]*)
(*NotebookOutlinePosition[      7754,        262]*)
(*  CellTagsIndexPosition[      7680,        256]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["EinsteinSum", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["EinsteinSum",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[
            RowBox[{"base", ":", "BaseIndices"}],
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  " will perform an Einstein summation on all pairs of matching up/down index \
pairs.  The range of the sum is over the base list, which has the default \
value of BaseIndices."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 The expansion will be done on individual terms, terms in sums, on both sides \
of an equation, and within arrays.\
\>", "MathCaption"],

Cell["\<\
No tensor label may be the same as one of the expansion indices, otherwise \
incorrect results will be obtained. If this unlikely case should occur you \
can reindex to avoid the problem.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ArrayExpansion",
    ButtonData:>{"ArrayExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SumExpansion",
    ButtonData:>{"SumExpansion"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EinsteinArray",
    ButtonData:>{"EinsteinArray"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToArrayValues",
    ButtonData:>{"ToArrayValues"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare base indices and flavors.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
            SuperDagger}};\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{x, y}, 1}, {{S, T}, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["EinsteinSum automatically extracts the summation indices.", "Text"],

Cell[BoxData[{
    \(xu[i] yd[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["EinsteinSum will not sum improper expressions.", "Text"],

Cell[BoxData[{
    \(xu[i] yu[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[10]:="],

Cell["EinsteinSum automatically handles flavored indices.", "Text"],

Cell[BoxData[{
    \(xu[i] yd[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[12]:="],

Cell["Nonmatching flavors do not sum.", "Text"],

Cell[BoxData[{
    \(xu[i] yd[red@i]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
A partial summation can be done over a subset of the base indices. The base \
subset is never flavored.\
\>", "Text"],

Cell[BoxData[{
    \(xu[i] yd[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[{1, 3}]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
An error occurs if the base specification is not a subset of BaseIndices.\
\>", "Text"],

Cell[BoxData[{
    \(xu[i] yd[i] // ToFlavor[red]\), "\n", 
    \(% // EinsteinSum[{1, 4}]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["It operates on sums on both sides of an equation...", "Text"],

Cell[BoxData[{
    \(xu[i] xd[i] + Sud[i, j] xu[j] \[Equal] 
      yu[i] yd[i] + Tud[i, j] yu[j]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[20]:="],

Cell["It will operated on equations and expressions within arrays.", "Text"],

Cell[BoxData[{
    \({xu[i] xd[i] + Sud[i, j] xu[j] \[Equal] yu[i] yd[i] + Tud[i, j] yu[j], 
      Sud[i, i] // ToFlavor[red]}\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
It sums on dot product expressions and CircleTimes expressions.\
\>", "Text"],

Cell[BoxData[{
    \(xu[i] . yd[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[{
    \(xu[i]\[CircleTimes]yd[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[26]:="],

Cell["Restore the initial values...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, y}, 1}, {{S, T}, 2}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[29]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 667, 24, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7509, 247}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 667, 24, 49, "Usage",
  CellTags->"Function?"],
Cell[2507, 82, 145, 3, 31, "MathCaption"],
Cell[2655, 87, 218, 4, 48, "MathCaption"],
Cell[2876, 93, 464, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3365, 115, 34, 0, 40, "ExampleSection"],
Cell[3402, 117, 96, 2, 29, "Input"],
Cell[3501, 121, 71, 0, 25, "Text"],
Cell[3575, 123, 359, 7, 109, "Input"],
Cell[3937, 132, 104, 2, 29, "Input"],
Cell[4044, 136, 73, 0, 25, "Text"],
Cell[4120, 138, 122, 3, 49, "Input"],
Cell[4245, 143, 62, 0, 25, "Text"],
Cell[4310, 145, 123, 3, 49, "Input"],
Cell[4436, 150, 67, 0, 25, "Text"],
Cell[4506, 152, 140, 3, 49, "Input"],
Cell[4649, 157, 47, 0, 25, "Text"],
Cell[4699, 159, 127, 3, 49, "Input"],
Cell[4829, 164, 127, 3, 25, "Text"],
Cell[4959, 169, 146, 3, 49, "Input"],
Cell[5108, 174, 97, 2, 25, "Text"],
Cell[5208, 178, 129, 3, 49, "Input"],
Cell[5340, 183, 67, 0, 25, "Text"],
Cell[5410, 185, 187, 4, 49, "Input"],
Cell[5600, 191, 76, 0, 25, "Text"],
Cell[5679, 193, 217, 4, 69, "Input"],
Cell[5899, 199, 87, 2, 25, "Text"],
Cell[5989, 203, 142, 3, 49, "Input"],
Cell[6134, 208, 153, 3, 49, "Input"],
Cell[6290, 213, 45, 0, 25, "Text"],
Cell[6338, 215, 104, 2, 29, "Input"],
Cell[6445, 219, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

