(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6119,        203]*)
(*NotebookOutlinePosition[      7112,        237]*)
(*  CellTagsIndexPosition[      7038,        231]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["EvaluateDotProducts", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"EvaluateDotProducts", "[", 
          StyleBox[
            RowBox[{"e", ",", "g", ",", " ", 
              RowBox[{"metricsimplify", ":", "True"}]}],
            "MR",
            FontSlant->"Italic"], 
          StyleBox["]",
            "MR",
            FontSlant->"Italic"]}], 
        StyleBox["[",
          "MR",
          FontSlant->"Italic"], "expr", 
        StyleBox["]",
          "MR",
          FontSlant->"Italic"]}]]],
  " expands Dot products of vectors expressed in a given basis e using the \
metric tensor g. Metric simplification is performed if the default argument \
metricsimplification is True."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Whether metric simplification is wanted depends upon whether values have been \
calculated for the metric tensor, or whether they have been calculated for \
the resulting tensors.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Dot",
    ButtonData:>{"Dot"},
    ButtonStyle->"RefGuideLink"],
  ", ",
  ButtonBox["LinearBreakout",
    ButtonData:>{"LinearBreakout"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["BasisDotProductRules",
    ButtonData:>{"BasisDotProductRules"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare the base indices and flavors.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell["Define tensor shortcuts.", "Text"],

Cell[BoxData[
    \(DefineTensorShortcuts[{{e, x, y}, 1}, {g, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
Dot products not involving e basis vectors are left unchanged.\
\>", "Text"],

Cell[BoxData[{
    \(u . v\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[e, \ g]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["Or they are partially simplified.", "Text"],

Cell[BoxData[{
    \(u . v /. {u \[Rule] xu[i] ed[i]}\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[e, \ g]\)}], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
If both arguments of the Dot function contain the e basis vectors, then it is \
fully evaluated.\
\>", "Text"],

Cell[BoxData[{
    \(u . v /. {u \[Rule] xu[i] ed[i], 
        v \[Rule] yu[j] ed[j]}\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[e, \ g]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[TextData[{
  "Sometimes you may not want metric simplification. Then set the 3rd \
optional argument to False. For example, suppose you have calculated and \
stored values for ",
  Cell[BoxData[
      RowBox[{"gdd", "[", 
        RowBox[{"i", ",", "j"}], "]"}]]],
  " and ",
  Cell[BoxData[
      RowBox[{"xu", "[", "i", "]"}]]],
  " but not ",
  Cell[BoxData[
      RowBox[{"xd", "[", "i", "]"}]]],
  ". Then you might prefer the following form."
}], "Text"],

Cell[BoxData[{
    \(u . v /. {u \[Rule] xu[i] ed[i], 
        v \[Rule] yu[j] ed[j]}\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[e, \ g, False]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  Cell[BoxData[
      RowBox[{"EvaluateDotProducts", Cell[""]}]]],
  "works on all dot products in an expression."
}], "Text"],

Cell[BoxData[{
    \(ed[i] . ed[j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[e, g]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["Restore the old values...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{e, x, y}, 1}, {g, 2}]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[20]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{669, 474},
WindowMargins->{{1, Automatic}, {Automatic, 5}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 66, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1845, 56, 750, 23, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6867, 222}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 66, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1845, 56, 750, 23, 49, "Usage",
  CellTags->"Function?"],
Cell[2598, 81, 210, 4, 48, "MathCaption"],
Cell[2811, 87, 358, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3194, 105, 34, 0, 40, "ExampleSection"],
Cell[3231, 107, 96, 2, 29, "Input"],
Cell[3330, 111, 75, 0, 25, "Text"],
Cell[3408, 113, 314, 6, 109, "Input"],
Cell[3725, 121, 40, 0, 25, "Text"],
Cell[3768, 123, 102, 2, 29, "Input"],
Cell[3873, 127, 86, 2, 25, "Text"],
Cell[3962, 131, 130, 3, 49, "Input"],
Cell[4095, 136, 49, 0, 25, "Text"],
Cell[4147, 138, 158, 3, 49, "Input"],
Cell[4308, 143, 120, 3, 25, "Text"],
Cell[4431, 148, 190, 4, 49, "Input"],
Cell[4624, 154, 464, 14, 42, "Text"],
Cell[5091, 170, 197, 4, 49, "Input"],
Cell[5291, 176, 142, 4, 27, "Text"],
Cell[5436, 182, 208, 4, 69, "Input"],
Cell[5647, 188, 41, 0, 25, "Text"],
Cell[5691, 190, 102, 2, 29, "Input"],
Cell[5796, 194, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

