(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7768,        262]*)
(*NotebookOutlinePosition[      8776,        297]*)
(*  CellTagsIndexPosition[      8702,        291]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ExpandLieD", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Expand", 
              StyleBox["LieD",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          StyleBox[
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                "x", ",", "\[Delta]", ",", "g", ",", "\[CapitalGamma]"}], 
                "}"}], ",", "a"}],
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will expand a first order Lie derivative of expr using coordinates x, \
Kronecker \[Delta] and dummy index a.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Expand", 
              StyleBox["LieD",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          StyleBox[
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                "x", ",", "\[Delta]", ",", "g", ",", "\[CapitalGamma]"}], 
                "}"}], ",", 
              RowBox[{"{", 
                RowBox[{"a", ",", "b", ",", "..."}], "}"}]}],
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will expand higher order Lie derivatives using the list ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c", ",", "..."}], "}"}]]],
  " as dummy indices."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " The Lie derivative is ambiguous until it is expanded to partial \
derivatives with ",
  Cell[BoxData["ExpandLieD"]],
  ", which provides the coordinates."
}], "MathCaption"],

Cell[TextData[{
  " A common set of tensor labels,",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "\[Delta]", ",", "g", ",", "\[CapitalGamma]"}], 
          "}"}]}]]],
  ", is used in all derivatives, even though every derivative does not used \
every label. It will often be convenient to set a variable to the list that \
you are using in your application."
}], "MathCaption"],

Cell[TextData[{
  "See also:  ",
  ButtonBox["LieD",
    ButtonData:>{"LieD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AbsoluteD",
    ButtonData:>{"AbsoluteD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CovariantD",
    ButtonData:>{"CovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{x, S, T, V, W}, 1}, {{\[Delta], S}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(SetTensorValues[\[Delta]ud[i, j], IdentityMatrix[NDim]]\)}], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
The Lie derivative takes on specific meaning when it is expanded to the \
partial derivative form.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i]\), "\[IndentingNewLine]", 
    \(LieD[%, V]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, a]\)}], "Input",
  CellLabel->"In[9]:="],

Cell["Lie derivative of a scalar tensor...", "Text"],

Cell[BoxData[{
    \(Tensor[\[Phi]]\), "\[IndentingNewLine]", 
    \(LieD[%, V]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, \[Mu]]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\)}], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
With flavored expressions, the flavor must also be on the expansion index.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(LieD[%, V]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, red@\[Mu]]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
Higher order derivatives are also supported and require additional dummy \
indices.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(LieD[%, {V, V}]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, red /@ {\[Mu], \[Nu]}]\)}], "Input",
  CellLabel->"In[19]:="],

Cell["Higher order derivatives are supported.", "Text"],

Cell[BoxData[{
    \(Tensor[\[Phi]] Tensor[\[Psi]]\), "\[IndentingNewLine]", 
    \(LieD[%, {V, V}]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, {a, b}]\)}], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
Lie derivative of a product of a scalar tensor and a 2nd order tensor with \
respect to two different vector fields.\
\>", "Text"],

Cell[BoxData[{
    \(Tensor[\[Phi]] Sud[i, j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(LieD[%, {V, W}]\), "\[IndentingNewLine]", 
    \(% // ExpandLieD[labs, red /@ {\[Mu], \[Nu]}]\)}], "Input",
  CellLabel->"In[25]:="],

Cell["Restore the settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, S, T, V, W}, 1}, {{\[Delta], S}, 
        2}]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[29]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{688, 464},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 1683, 60, 89, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8530, 282}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 1683, 60, 89, "Usage",
  CellTags->"Function?"],
Cell[3522, 118, 193, 5, 48, "MathCaption"],
Cell[3718, 125, 419, 10, 48, "MathCaption"],
Cell[4140, 137, 513, 22, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4678, 163, 34, 0, 40, "ExampleSection"],
Cell[4715, 165, 96, 2, 29, "Input"],
Cell[4814, 169, 34, 0, 25, "Text"],
Cell[4851, 171, 268, 5, 89, "Input"],
Cell[5122, 178, 310, 6, 69, "Input"],
Cell[5435, 186, 122, 3, 25, "Text"],
Cell[5560, 191, 166, 4, 69, "Input"],
Cell[5729, 197, 52, 0, 25, "Text"],
Cell[5784, 199, 232, 5, 89, "Input"],
Cell[6019, 206, 98, 2, 25, "Text"],
Cell[6120, 210, 192, 4, 69, "Input"],
Cell[6315, 216, 107, 3, 25, "Text"],
Cell[6425, 221, 209, 4, 69, "Input"],
Cell[6637, 227, 55, 0, 25, "Text"],
Cell[6695, 229, 201, 4, 69, "Input"],
Cell[6899, 235, 140, 3, 25, "Text"],
Cell[7042, 240, 228, 4, 69, "Input"],
Cell[7273, 246, 37, 0, 25, "Text"],
Cell[7313, 248, 129, 3, 29, "Input"],
Cell[7445, 253, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

