(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6597,        225]*)
(*NotebookOutlinePosition[      7604,        260]*)
(*  CellTagsIndexPosition[      7530,        254]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ExpandPartialD", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Expand", 
              StyleBox["PartialD",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          StyleBox[\({x, \[Delta], \ g, \ \[CapitalGamma]}\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands the partial derivatives using the coordinate label x and the \
Kronecker label \[Delta]."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 The partial derivative of a tensor is not itself a tensor. However, it is \
used along with the Christoffel symbols in calculating the covariant \
derivative, which is a proper tensor.\
\>", "MathCaption"],

Cell[TextData[{
  "ExpandPartialD is just a delayed form of ",
  Cell[BoxData[
      \(PartialD[labs]\)]],
  " and it does not directly allow you to introduce partial derivatives with \
respect to symbols."
}], "MathCaption"],

Cell[TextData[{
  " In ",
  Cell[BoxData[
      \(ExpandPartialD\)]],
  " the extended list of labels ",
  Cell[BoxData[
      \({x, \[Delta], g, \[CapitalGamma]}\)]],
  ", for coordinate, Kronecker, metric and Christoffel labels, is given to be \
in conformity with similar usage with the other derivatives. Only ",
  Cell[BoxData[
      \(x\)]],
  " and ",
  Cell[BoxData[
      \(\[Delta]\)]],
  " are actually used with ",
  Cell[BoxData[
      \(ExpandPartialD\)]],
  ". "
}], "MathCaption"],

Cell[TextData[{
  "When working in a notebook with a constant set of labels one can put ",
  Cell[BoxData[
      \(labs = {x, \[Delta], g, \[CapitalGamma]}\)]],
  "and then use ",
  Cell[BoxData[
      \(\(ExpandPartialD[labs]\)[expr]\)]],
  ", with similar usage for the other derivative expansion routines."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NondependentPartialD",
    ButtonData:>{"NondependentPartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CovariantD",
    ButtonData:>{"CovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AbsoluteD",
    ButtonData:>{"AbsoluteD"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save settings.", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{x, T}, 1}, {{S, T, \[Delta]}, 2}]\)], "Input",
  CellLabel->"In[5]:="],

Cell["Set the standard labels to be used in the examples.", "Text"],

Cell[BoxData[
    \(\(labs = {x, \[Delta], g, \[CapitalGamma]};\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "Without information as to the coordinate, a partial derivative simply \
shows a comma before each differentiated index. These expressions can be \
expanded to explicit partial derivatives by using ",
  Cell[BoxData[
      \(ExpandPartialD\)]],
  " and supplying the coordinate and Kronecker labels."
}], "Text"],

Cell[BoxData[{
    \(Td[i]\), "\[IndentingNewLine]", 
    \(PartialD[%, j]\), "\[IndentingNewLine]", 
    \(% // ExpandPartialD[labs]\)}], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
For flavored expressions, the flavor must also be on the derivative index, \
but nothing further is needed in expanding.\
\>", "Text"],

Cell[BoxData[{
    \(Td[i] + xu[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(PartialD[%, red@j]\), "\[IndentingNewLine]", 
    \(% // ExpandPartialD[labs]\)}], "Input",
  CellLabel->"In[10]:="],

Cell["All the tensors containing partial derivatives are expanded.", "Text"],

Cell[BoxData[{
    \({xu[i] + Tu[i], 2  xu[i] Tu[j], Tu[i] Sud[p, i]} // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(\(PartialD[#, red@k] &\) /@ %\), "\[IndentingNewLine]", 
    \(% // ExpandPartialD[labs]\)}], "Input",
  CellLabel->"In[13]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, T}, 1}, {{S, T, \[Delta]}, 2}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[{
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[oldflavors];\)\), "\[IndentingNewLine]", 
    \(Clear[oldflavors, labs]\)}], "Input",
  CellLabel->"In[17]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 641, 24, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7359, 245}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 641, 24, 32, "Usage",
  CellTags->"Function?"],
Cell[2484, 82, 216, 4, 48, "MathCaption"],
Cell[2703, 88, 225, 6, 48, "MathCaption"],
Cell[2931, 96, 496, 18, 65, "MathCaption"],
Cell[3430, 116, 328, 8, 48, "MathCaption"],
Cell[3761, 126, 544, 22, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4330, 152, 34, 0, 40, "ExampleSection"],
Cell[4367, 154, 96, 2, 29, "Input"],
Cell[4466, 158, 30, 0, 25, "Text"],
Cell[4499, 160, 205, 4, 69, "Input"],
Cell[4707, 166, 114, 2, 29, "Input"],
Cell[4824, 170, 67, 0, 25, "Text"],
Cell[4894, 172, 102, 2, 29, "Input"],
Cell[4999, 176, 330, 7, 59, "Text"],
Cell[5332, 185, 171, 4, 69, "Input"],
Cell[5506, 191, 144, 3, 25, "Text"],
Cell[5653, 196, 201, 4, 69, "Input"],
Cell[5857, 202, 76, 0, 25, "Text"],
Cell[5936, 204, 254, 5, 69, "Input"],
Cell[6193, 211, 33, 0, 25, "Text"],
Cell[6229, 213, 114, 2, 29, "Input"],
Cell[6346, 217, 223, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

