(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8125,        279]*)
(*NotebookOutlinePosition[      9133,        314]*)
(*  CellTagsIndexPosition[      9059,        308]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ExpandTotalD", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Expand", 
              StyleBox["TotalD",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          RowBox[{
            StyleBox[\({x, \[Delta], g, \[CapitalGamma]}\),
              "MR"], 
            StyleBox[",",
              "MR"], 
            StyleBox["a",
              "TI"]}], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands total derivative expressions with coordinate label x and \
Kronecker label \[Delta] using a as the dummy index.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Expand", 
              StyleBox["TotalD",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          RowBox[{
            StyleBox[\({x, \[Delta], g, \[CapitalGamma]}\),
              "MR"], 
            StyleBox[",",
              "MR"], 
            StyleBox[\({a, b,  ... }\),
              "TI"]}], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands higher order derivatives."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 Tensors are funtions of the coordinates and any variation of the tensor is \
due to the variation of the coordiates over the parameter of differentiation \
used.   Tensors are not allowed to depend on the parameters directly but only \
through the coordinates.! \
\>", "MathCaption"],

Cell["\<\
 For multiple differentiations, a dummy index for each differentiation must \
be given.\
\>", "MathCaption"],

Cell[" The dummy indices must be in the desired flavor.", "MathCaption"],

Cell[TextData[{
  " A common set of tensor labels,",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"{", 
          RowBox[{"x", ",", "\[Delta]", ",", "g", ",", "\[CapitalGamma]"}], 
          "}"}]}]]],
  ", is used in all derivatives, even though every derivative does not used \
every label. It will often be convenient to set a variable to the list that \
you are using in your application."
}], "MathCaption"],

Cell["\<\
 Total derivative expressions are fully evaluated when a tensor is expanded \
to its components.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CovariantD",
    ButtonData:>{"CovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AbsoluteD",
    ButtonData:>{"AbsoluteD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ExpandPartialD",
    ButtonData:>{"ExpandPartialD"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell["We set the Euclidean metric and coordinates.", "Text"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(\(labs = {x, \[Delta], 
          g, \[CapitalGamma]};\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{{x, F}, 1}, {{g, \[Delta]}, 
        2}]\), "\[IndentingNewLine]", 
    \(SetTensorValues[\[Delta]ud[i, j], IdentityMatrix[3]]\)}], "Input",
  CellLabel->"In[6]:="],

Cell["Here is the total derivative of a tensor F...", "Text"],

Cell[BoxData[{
    \(Fu[i]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\)}], "Input",
  CellLabel->"In[9]:="],

Cell[TextData[{
  "The actual meaning of ",
  Cell[BoxData[
      \(TotalD\)]],
  " is..."
}], "Text"],

Cell[BoxData[{
    \(Fu[i]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\), "\[IndentingNewLine]", 
    \(% // ExpandTotalD[labs, a]\)}], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
Here is a second order differentiation. For a flavored expression, the dummy \
indices must be in the desired flavor.\
\>", "Text"],

Cell[BoxData[{
    \(Fu[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(TotalD[%, {t, t}]\), "\[IndentingNewLine]", 
    \(% // ExpandTotalD[labs, red /@ {a, b}]\)}], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
Here, we calculate the acceleration of a particle moving on a circular \
path.\
\>", "Text"],

Cell[BoxData[
    \(SetTensorValueRules[xu[i], {Sin[t], Cos[t], 0}]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[{
    \(TotalD[xu[i], {t, t}]\), "\[IndentingNewLine]", 
    \(% // ExpandTotalD[labs, {a, b}]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues[]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["A total derivative of a partial derivatice of a tensor.", "Text"],

Cell[BoxData[{
    \(ClearTensorValues[xu[i]]\), "\n", 
    \(Fu[k]\), "\n", 
    \(PartialD[%, m]\), "\n", 
    \(TotalD[%, t]\), "\n", 
    \(\(ExpandTotalD[labs, i]\)[%]\), "\n", 
    \(\(ExpandPartialD[labs]\)[%]\)}], "Input",
  CellLabel->"In[21]:="],

Cell["Or expanding in a different order.", "Text"],

Cell[BoxData[{
    \(ClearTensorValues[xu[i]]\), "\n", 
    \(Fu[k]\), "\n", 
    \(PartialD[%, m]\), "\n", 
    \(\(ExpandPartialD[labs]\)[%]\), "\n", 
    \(TotalD[%, t]\), "\n", 
    \(\(ExpandTotalD[labs, i]\)[%]\)}], "Input",
  CellLabel->"In[27]:="],

Cell["Restore the sesttings", "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues /@ {xu[i], \[Delta]ud[i, 
            j]};\)\), "\[IndentingNewLine]", 
    \(ClearTensorShortcuts[{{x, F}, 1}, {{g, \[Delta]}, 2}]\)}], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[35]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 1430, 54, 72, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8887, 299}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 1430, 54, 72, "Usage",
  CellTags->"Function?"],
Cell[3271, 112, 294, 5, 65, "MathCaption"],
Cell[3568, 119, 118, 3, 31, "MathCaption"],
Cell[3689, 124, 72, 0, 31, "MathCaption"],
Cell[3764, 126, 419, 10, 48, "MathCaption"],
Cell[4186, 138, 127, 3, 31, "MathCaption"],
Cell[4316, 143, 532, 22, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4873, 169, 34, 0, 40, "ExampleSection"],
Cell[4910, 171, 60, 0, 25, "Text"],
Cell[4973, 173, 96, 2, 29, "Input"],
Cell[5072, 177, 34, 0, 25, "Text"],
Cell[5109, 179, 268, 5, 89, "Input"],
Cell[5380, 186, 298, 6, 69, "Input"],
Cell[5681, 194, 61, 0, 25, "Text"],
Cell[5745, 196, 110, 3, 49, "Input"],
Cell[5858, 201, 102, 5, 25, "Text"],
Cell[5963, 208, 171, 4, 69, "Input"],
Cell[6137, 214, 141, 3, 25, "Text"],
Cell[6281, 219, 205, 4, 69, "Input"],
Cell[6489, 225, 102, 3, 25, "Text"],
Cell[6594, 230, 105, 2, 29, "Input"],
Cell[6702, 234, 200, 4, 69, "Input"],
Cell[6905, 240, 71, 0, 25, "Text"],
Cell[6979, 242, 255, 7, 129, "Input"],
Cell[7237, 251, 50, 0, 25, "Text"],
Cell[7290, 253, 255, 7, 129, "Input"],
Cell[7548, 262, 37, 0, 25, "Text"],
Cell[7588, 264, 211, 4, 49, "Input"],
Cell[7802, 270, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

