(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4283,        151]*)
(*NotebookOutlinePosition[      5269,        185]*)
(*  CellTagsIndexPosition[      5195,        179]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["GenerateBasisTensors", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["GenerateBasisTensors",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[
          RowBox[{"e", ",", "configuration"}],
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will generate the set of basis tensors on basis vectors e with a a given \
configuration of up and down basis vectors. "
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 The configuration is specified by a String of u's and d's for up and down.\
\>", "MathCaption"],

Cell["It is assumed that tensor shortcuts have been defined for e.", \
"MathCaption"],

Cell[TextData[{
  "The basis is generated as an array of ",
  Cell[BoxData[
      \(CircleTimes\)]],
  " expressions of the basis vectors."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CircleEvalRule",
    ButtonData:>{"CircleEvalRule"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvaluateSlots",
    ButtonData:>{"EvaluateSlots"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[e, 1]\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "With the basis vectors themselves we may or may not wish to eliminate the \
",
  Cell[BoxData["CircleTimes"]],
  ", depending on how we are going to use them."
}], "Text"],

Cell[BoxData[{
    \(basis1 = GenerateBasisTensors[e, "\<d\>"]\), "\[IndentingNewLine]", 
    \(basis2 = 
      GenerateBasisTensors[e, "\<u\>"] /. 
        CircleTimes \[Rule] Identity\), "\[IndentingNewLine]", 
    \(\(\((basis1 . #)\)[basis2 . #] &\)[{a, b, 
        c}]\), "\[IndentingNewLine]", 
    \(% // EvaluateSlots[e, g]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["The various 2nd order basis dyads.", "Text"],

Cell[BoxData[
    \(\(\(Print[
            GenerateBasisTensors[
              e, #]] &\) /@ {"\<uu\>", "\<ud\>", "\<du\>", "\<dd\>"};\)\)], \
"Input",
  CellLabel->"In[7]:="],

Cell["A set of 3rd order basis triads.", "Text"],

Cell[BoxData[
    \(GenerateBasisTensors[e, "\<uuu\>"]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[{
    \(ClearTensorShortcuts[e, 1]\), "\[IndentingNewLine]", 
    \(Clear[basis1, basis2]\)}], "Input",
  CellLabel->"In[9]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{674, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 67, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1846, 56, 461, 16, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5024, 170}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 67, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1846, 56, 461, 16, 49, "Usage",
  CellTags->"Function?"],
Cell[2310, 74, 106, 2, 31, "MathCaption"],
Cell[2419, 78, 85, 1, 31, "MathCaption"],
Cell[2507, 81, 158, 5, 31, "MathCaption"],
Cell[2668, 88, 258, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2951, 102, 34, 0, 40, "ExampleSection"],
Cell[2988, 104, 96, 2, 29, "Input"],
Cell[3087, 108, 84, 2, 29, "Input"],
Cell[3174, 112, 190, 5, 42, "Text"],
Cell[3367, 119, 369, 8, 89, "Input"],
Cell[3739, 129, 50, 0, 25, "Text"],
Cell[3792, 131, 175, 5, 29, "Input"],
Cell[3970, 138, 48, 0, 25, "Text"],
Cell[4021, 140, 91, 2, 29, "Input"],
Cell[4115, 144, 140, 3, 49, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

