(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6549,        227]*)
(*NotebookOutlinePosition[      7536,        261]*)
(*  CellTagsIndexPosition[      7462,        255]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["IndexChange", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["IndexChange",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\({{r, i}, {s, j} ... }, sign : 1\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will replace the first index in each pair list by the second index in the \
pair list everywhere in the expression and multiply the expression by sign, \
which has the default value of 1.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["IndexChange",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\({r, i}, sign : 1\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " may be used for a single index change."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 IndexChange can be used to perform specific reindexing under the user's \
control\
\>", "MathCaption"],

Cell["\<\
 At present the routine does not check if the indices actually exist in the \
expression and hence could effect a sign change without an index change.\
\>", "MathCaption"],

Cell["\<\
 DummySimplify will perform automatic reindexing in an attempt to simplify \
tensor expressions.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["EinsteinSum",
    ButtonData:>{"EinsteinSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SimplifyTensorSum",
    ButtonData:>{"SimplifyTensorSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DummySimplify",
    ButtonData:>{"DummySimplify"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SymmetrizeSlots",
    ButtonData:>{"SymmetrizeSlots"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save old values and declare a flavor.", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{A, B}, 1}, {{A, B}, 2}]\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
DummySimplify will usually perform the desired dummy index simplification in \
expressions.\
\>", "Text"],

Cell[BoxData[{
    \(expr1 = 
      a\ Ad[j] Bu[j] + b\ Ad[m] Bu[m] + 
        c\ Ad[i] Bu[i]\), "\[IndentingNewLine]", 
    \(\(% // DummySimplify\) // Factor\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[{
    \(expr1 // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(\(% // DummySimplify\) // Factor\)}], "Input",
  CellLabel->"In[8]:="],

Cell["But we could also do it \"by hand\".", "Text"],

Cell[BoxData[{
    \(expr1\), "\[IndentingNewLine]", 
    \(\(% // IndexChange[{{j, i}, {m, i}}]\) // Factor\)}], "Input",
  CellLabel->"In[10]:="],

Cell["You can use flavored or unflavored indices.", "Text"],

Cell[BoxData[{
    \(expr1 // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(\(% // IndexChange[{{j, i}, {m, i}}]\) // Factor\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[{
    \(expr1 // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(\(% // IndexChange[{red /@ {j, i}, red /@ {m, i}}]\) // 
      Factor\)}], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
A single index change can be entered without the extra brakets. If we didn't \
like the choice of indices made by DummySimplify, we could use IndexChange \
for a final adjustment.\
\>", "Text"],

Cell[BoxData[{
    \(expr1\), "\[IndentingNewLine]", 
    \(\(% // DummySimplify\) // Simplify\), "\[IndentingNewLine]", 
    \(% // IndexChange[{i, k}]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
Here we implement an antisymmetry in a tensor expression by specifying the \
sign as -1.\
\>", "Text"],

Cell[BoxData[{
    \(Add[i, j] Buu[k, l]\), "\[IndentingNewLine]", 
    \(% // IndexChange[{{j, k}, {k, j}}, \(-1\)]\)}], "Input",
  CellLabel->"In[19]:="],

Cell["Restore settings", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{A, B}, 1}, {{A, B}, 2}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[{
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[expr1, oldflavors]\)}], "Input",
  CellLabel->"In[22]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{669, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 58, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1837, 56, 1114, 41, 72, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7290, 246}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 58, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1837, 56, 1114, 41, 72, "Usage",
  CellTags->"Function?"],
Cell[2954, 99, 113, 3, 31, "MathCaption"],
Cell[3070, 104, 181, 3, 48, "MathCaption"],
Cell[3254, 109, 127, 3, 31, "MathCaption"],
Cell[3384, 114, 472, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3881, 136, 36, 0, 40, "ExampleSection"],
Cell[3920, 138, 96, 2, 29, "Input"],
Cell[4019, 142, 53, 0, 25, "Text"],
Cell[4075, 144, 205, 4, 69, "Input"],
Cell[4283, 150, 104, 2, 29, "Input"],
Cell[4390, 154, 115, 3, 25, "Text"],
Cell[4508, 159, 197, 5, 49, "Input"],
Cell[4708, 166, 147, 3, 49, "Input"],
Cell[4858, 171, 52, 0, 25, "Text"],
Cell[4913, 173, 147, 3, 49, "Input"],
Cell[5063, 178, 59, 0, 25, "Text"],
Cell[5125, 180, 164, 3, 49, "Input"],
Cell[5292, 185, 185, 4, 49, "Input"],
Cell[5480, 191, 203, 4, 42, "Text"],
Cell[5686, 197, 191, 4, 69, "Input"],
Cell[5880, 203, 112, 3, 25, "Text"],
Cell[5995, 208, 155, 3, 49, "Input"],
Cell[6153, 213, 32, 0, 25, "Text"],
Cell[6188, 215, 104, 2, 29, "Input"],
Cell[6295, 219, 226, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

