(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4383,        149]*)
(*NotebookOutlinePosition[      5368,        183]*)
(*  CellTagsIndexPosition[      5294,        177]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["IndexFlavors", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData["IndexFlavors"]],
  " gives the current set of index flavors and their forms."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Index flavors are used to distinguish various coordinate systems or reference \
frames.\
\>", "MathCaption"],

Cell[TextData[{
  "\"The bars, primes, and hats [on the indices] distinguish one coordinate \
system from another: by putting them on the indices rather than on [the \
labels] we simplify later notation.\" Charles W. Misner, Kip S. Thorne & John \
Archibald Wheeler, ",
  StyleBox["Gravitation",
    FontSlant->"Italic"],
  ", p9."
}], "MathCaption"],

Cell[TextData[{
  "According to J. Forster & J.D. Nightingale in  ",
  StyleBox["A Short Course in General Relativity",
    FontSlant->"Italic"],
  ", this \"is part of the ",
  StyleBox["kernel-index method",
    FontSlant->"Italic"],
  " initiated by Shouten and his co-workers.\" (Schouten, J.A. (1954) ",
  StyleBox["Ricci-Calculus",
    FontSlant->"Italic"],
  ", 2nd ed., Springer, Berlin)"
}], "MathCaption"],

Cell[TextData[{
  "See the entries under ",
  Cell[BoxData["DeclareIndexFlavor"]],
  " for further details of specifying flavors."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["DeclareIndexFlavor",
    ButtonData:>{"DeclareIndexFlavor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClearIndexFlavor",
    ButtonData:>{"ClearIndexFlavor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ToFlavor",
    ButtonData:>{"ToFlavor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IndexFlavorQ",
    ButtonData:>{"IndexFlavorQ"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["The following gives the current set of of index flavors.", "Text"],

Cell[BoxData[
    \(oldflavors = IndexFlavors\)], "Input",
  CellLabel->"In[2]:="],

Cell["This declares new index flavors.", "Text"],

Cell[BoxData[{
    \(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
          SuperStar}}; \), "\[IndentingNewLine]", 
    \(IndexFlavors // StandardForm\)}], "Input",
  CellLabel->"In[3]:="],

Cell["This resets to the old indices.", "Text"],

Cell[BoxData[{
    \(ClearIndexFlavor /@ IndexFlavors; \), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor /@ oldflavors; \), "\[IndentingNewLine]", 
    \(Clear[oldflavors]\)}], "Input",
  CellLabel->"In[5]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 59, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1838, 56, 174, 5, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5124, 168}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1838, 56, 174, 5, 32, "Usage",
  CellTags->"Function?"],
Cell[2015, 63, 118, 3, 31, "MathCaption"],
Cell[2136, 68, 350, 8, 65, "MathCaption"],
Cell[2489, 78, 415, 11, 48, "MathCaption"],
Cell[2907, 91, 149, 4, 31, "MathCaption"],
Cell[3059, 97, 468, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3552, 119, 36, 0, 40, "ExampleSection"],
Cell[3591, 121, 96, 2, 29, "Input"],
Cell[3690, 125, 72, 0, 25, "Text"],
Cell[3765, 127, 82, 2, 29, "Input"],
Cell[3850, 131, 48, 0, 25, "Text"],
Cell[3901, 133, 189, 4, 49, "Input"],
Cell[4093, 139, 47, 0, 25, "Text"],
Cell[4143, 141, 212, 4, 69, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

