(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     16144,        561]*)
(*NotebookOutlinePosition[     16887,        587]*)
(*  CellTagsIndexPosition[     16843,        583]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Introduction to Tensorial 3.0", "Title"],

Cell["\<\
Renan Cabrera  MSc., PhD Student
Physics Dept., University of Windsor
Windsor, ON, Canada N9B 3P4
rencabla@ceibo.entelnet.bo

David Park
5605 West Falls Road
Mount Airy, Maryland 21771, USA
djmp@earthlink.net

Jean-Fran\[CCedilla]ois Gouyet
Labo. PMC
Ecole Polytechnique
F-91128 Palaiseau Cedex, France
jean-francois.gouyet@polytechnique.fr\
\>", "Subsubtitle"],

Cell[TextData[{
  "Tensorial is a general purpose tensor calculus package for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 4.1 or later. We have tried to design it as an open system and \
natural extension of ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " with routines that give access to all levels of tensor calculations. Thus \
it should be useful for students first learning tensor calculus and for \
advanced calculations. We also hope that the open design will make it easy to \
extend Tensorial to special purpose areas by adding subsidiary packages."
}], "Text"],

Cell["\<\
We consider Tensorial as a continuing project. Anyone who wishes to \
participate in the project should feel free to contact one of the authors \
above. We also appreciate any criticisms and suggestions.\
\>", "Text"],

Cell[TextData[{
  "Tensorial is freely available to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " community. Our only request is that if you make a publication extensively \
using Tensorial you reference the package and principal authors."
}], "Text"],

Cell[CellGroupData[{

Cell["Design Principles", "Section"],

Cell[TextData[{
  "Many of the design principles we used in Tensorial were inspired by the ",
  StyleBox["Gravitation",
    FontSlant->"Italic"],
  " book by Charles W. Misner, Kip S. Thorne & John Archibald Wheeler."
}], "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] No special symbols. No restrictions. For example, the \
base indices for a coordinate system can be any set of integers or symbols: \
",
  Cell[BoxData[
      \({1, 2, 3}\)]],
  " for 3D Cartesian coordinates, ",
  Cell[BoxData[
      \({0, 1, 2, 3}\)]],
  " or ",
  Cell[BoxData[
      \({t, x, y, z}\)]],
  " for relativity problems, or ",
  Cell[BoxData[
      \({\[Rho], \[Theta], \[Phi]}\)]],
  "for spherical coordinates."
}], "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] No special tensor labels. You can use any labels you \
want for any kind of tensor. You can use ",
  Cell[BoxData[
      \(\[Delta]\)]],
  " for a Kronecker or you can use ",
  Cell[BoxData[
      \(\[Kappa]\)]],
  ". You can use ",
  Cell[BoxData[
      \(g\)]],
  " for the metric tensor or you can use ",
  Cell[BoxData[
      \(\[Eta]\)]],
  ". You can even have several types of Kroneckers or metric tensors in play \
at once. All the special properties of tensors are contained in the routines \
that process the tensors and not in their labels. This means that the \
intended labels must be fed to the routines. So ",
  Cell[BoxData[
      \(MetricSimplify[g]\)]],
  " will do metric simplification assuming that 2nd order tensors with the \
label ",
  Cell[BoxData[
      \(g\)]],
  " are metric tensors. ",
  Cell[BoxData[
      \(MetricSimplify[\[Eta]]\)]],
  " would use ",
  Cell[BoxData[
      \(\[Eta]\)]],
  " label tensors as metric tensors and not ",
  Cell[BoxData[
      \(g\)]],
  " label tensors. The disadvantage of this is that one has to feed the \
tensor labels to routines. The benefit is that you can be certain that no \
special definitions will be applied to a tensor just because you haplessly \
picked some label for it. You can adapt your notation to the field or \
textbook you are working in."
}], "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] Coordinate systems are designated on the indices and \
not on the tensor labels. To facilitate this, ",
  StyleBox["index flavors",
    FontSlant->"Italic"],
  " have been introduced. An index flavor is either a color or an annotated \
symbol such as ",
  Cell[BoxData[
      \(OverHat[i]\)]],
  ". Thus you could have regular black indices for one coordinate system and \
red colored indices for another coordinate system. Sometimes it is nice to \
use colored indices just to make them better stand out. See the Index Flavors \
section in the Tensorial 3.0 Help to see how this is implemented."
}], "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] One slot, one index. Every tensor, or indexed object, \
can have upper and lower indices. An upper index will always have a blank \
space below it, and conversely a lower index will always have a blank space \
above it. Although there is theoretical justification for just treating up \
indices and down indices separately and putting one above the other, the ",
  StyleBox["one slot - one index",
    FontSlant->"Italic"],
  " rule vastly simplifies the programming and reduces confusion. When a \
single upper index is lowered, without the rule, is it put at the beginning \
or end of the lower indices?"
}], "Text"],

Cell["\<\
\[FilledSmallSquare] Some programming required. We are trying to build from \
the ground up by providing a convenient, versatile and rich suite of routines \
for manipulating tensor expressions and calculating the various derivatives. \
We have not yet provided automatic routines for every interesting tensor. We \
hope we have provided the tools so you can calculate the tensors that \
interest you.\
\>", "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] Give Help. Documentation is as important as the code. \
We have provided regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " style documentation, with a Help page for each command as well as \
additional tutorial and example notebooks. Each help page contains examples \
for the command that illustrates its basic usage and we have occasionally \
attempted to slip in more advanced calculations. Using Tensorial\\Tensorial \
Basics and then working through the Help pages will be the best way to learn \
Tensorial."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["A Sample Calculation", "Section"],

Cell["\<\
Here we show a short calculation performed with Tensorial. In any notebook \
you will have to:
1) Load the package
2) Declare the base indices if they are different from the default.
3) Define tensor shortcuts for the tensors you will be using.
4) Declare any index flavors you will be using.\
\>", "Text"],

Cell[TextData[{
  "We will calculate the length of a specific curve on the surface of a \
sphere of radius ",
  Cell[BoxData[
      \(a\)]],
  ", described in spherical coordinates. "
}], "Text"],

Cell["The Tensorial package can be loaded with the statement...", "Text"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input"],

Cell[TextData[{
  "We will use ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{"\[Rho]", ",", "\[Theta]", ",", "\[Phi]"}], "}"}]]],
  " as our base indices."
}], "Text"],

Cell[BoxData[
    \(DeclareBaseIndices[{\[Rho], \[Theta], \[Phi]}]\)], "Input"],

Cell[TextData[{
  "We define tensor shortcuts for the tensors we will use. ",
  Cell[BoxData[
      \(x\)]],
  " is a coordinate vector, ",
  Cell[BoxData[
      \(v\)]],
  " the velocity vector and ",
  Cell[BoxData[
      \(g\)]],
  " the metric tensor."
}], "Text"],

Cell[BoxData[
    \(DefineTensorShortcuts[{{x, v}, 1}, {g, 2}]\)], "Input"],

Cell[TextData[{
  "We declare a red index flavor. red is the name of the flavor and Red is \
the actual RGBColor. (",
  Cell[BoxData[
      \(Graphics`Colors`\)]],
  " is automatically loaded by Tensorial.) "
}], "Text"],

Cell[BoxData[
    \(DeclareIndexFlavor[{red, Red}]\)], "Input"],

Cell["\<\
We define the metric tensor in conventional coordinates and then convert it \
to tensor coordinates.\
\>", "Text"],

Cell[BoxData[{
    \(cmetric = 
      DiagonalMatrix[{1, \[Rho]\^2, \(\[Rho]\^2\) 
            Sin[\[Theta]]\^2}]\), "\[IndentingNewLine]", 
    \(metric = 
      cmetric // CoordinatesToTensors[{\[Rho], \[Theta], \[Phi]}, x, 
          red]\)}], "Input"],

Cell["\<\
We then set rules for the values of the metric tensor. The inverse metric \
values are also automatically calculated and stored.\
\>", "Text"],

Cell[BoxData[
    \(SetMetricValueRules[g, \ metric, \ red]\)], "Input"],

Cell["We can look at the nonzero values with", "Text"],

Cell[BoxData[
    \(NonzeroValueRules[g] // TableForm\)], "Input"],

Cell[TextData[{
  "We also set value rules for the curve followed by ",
  Cell[BoxData[
      \(x\)]],
  ". This is our first explicit use of a tensor shortcut. ",
  Cell[BoxData[
      \(xu[red@i]\)]],
  " stands for the ",
  Cell[BoxData[
      \(x\)]],
  " tensor with an up index in the red flavor. The curve is at a constant \
radius ",
  Cell[BoxData[
      \(a\)]],
  ", and for ",
  Cell[BoxData[
      \(0 \[LessEqual] t \[LessEqual] \[Pi]\)]],
  " moves from the North pole to the South pole while wrapping once around \
the sphere."
}], "Text"],

Cell[BoxData[
    \(SetTensorValueRules[xu[red@i], {a, t, 2  t}]\)], "Input"],

Cell[TextData[{
  "The velocity is the total derivative of the coordinate. We have not yet \
told ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that ",
  Cell[BoxData["a"]],
  " is a constant."
}], "Text"],

Cell[BoxData[{
    \(TotalD[xu[red@i], t]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues[]\)}], "Input"],

Cell["\<\
We set the velocity tangent vector to the total derivative of the coordinate \
vector.\
\>", "Text"],

Cell[BoxData[
    \(SetTensorValueRules[vu[red@i], 
      TotalD[xu[red@i], \ t] // ToArrayValues[]]\)], "Input"],

Cell[TextData[{
  "We now calculate the line element along the curve, using the tangent \
velocity vectors and the metric tensor. We do an Einstein summation and then \
substitute the tensor value rules for ",
  Cell[BoxData[
      \(g\)]],
  ", ",
  Cell[BoxData[
      \(v\)]],
  " and ",
  Cell[BoxData[
      \(x\)]],
  ". (This is a little tricky because we had to do multiple substitutions. ",
  Cell[BoxData[
      \(x\)]],
  " appears only after ",
  Cell[BoxData[
      \(v\)]],
  " is substituted.) We set ",
  Cell[BoxData[
      \(a\)]],
  " to be a constant to eliminate total derivatives of ",
  Cell[BoxData[
      \(a\)]],
  ". Here again we use tensor shortcuts. ",
  Cell[BoxData[
      \(gdd[i, j]\)]],
  " is the down version of the metric tensor."
}], "Text"],

Cell[BoxData[{
    \(SetAttributes[a, Constant]\), "\[IndentingNewLine]", 
    \(gdd[i, j] vu[i] vu[j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(% //. TensorValueRules[g, v, x]\), "\[IndentingNewLine]", 
    \(lineElement = Simplify[\@%, a > 0]\), "\[IndentingNewLine]", 
    \(ClearAll[a]\)}], "Input"],

Cell[TextData[{
  "The calculation could be shortened using the ",
  Cell[BoxData["ToArrayValues"]],
  " routine."
}], "Text"],

Cell[BoxData[{
    \(SetAttributes[a, Constant]\), "\[IndentingNewLine]", 
    \(gdd[i, j] vu[i] vu[j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues[]\), "\[IndentingNewLine]", 
    \(lineElement = Simplify[\@%, a > 0]\), "\[IndentingNewLine]", 
    \(ClearAll[a]\)}], "Input"],

Cell["Now we can calculate the length of the curve.", "Text"],

Cell[BoxData[{
    \(\[Integral]\_0\%\[Pi] lineElement \[DifferentialD]t // 
      StandardForm\), "\[IndentingNewLine]", 
    \(% // N\)}], "Input"],

Cell["Restore settings.", "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues /@ {xu[red@i], vu[red@i], guu[red@i, red@j], 
          gdd[red@i, red@j]};\)\), "\[IndentingNewLine]", 
    \(ClearTensorShortcuts[{{x, v}, 1}, {g, 2}]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor[red];\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Update History & Usage Changes", "Section"],

Cell["\<\
This section itemizes significant additions or changes in usage to Tensorial. \
See the relevant Help pages for full details of the commands.\
\>", "Text"],

Cell[CellGroupData[{

Cell["17 Sep 2003", "Subsection"],

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(SetTensorValues\)]],
  " and ",
  Cell[BoxData[
      \(SetTensorValueRules\)]],
  " modified to allow suspension of size checking on value arrays. Allows \
additional functionality but compatible with old usage."
}], "Text"],

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(ToArrayValues\)]],
  " usage changed to allow expansion on a subset of indices as with ",
  Cell[BoxData[
      \(EinsteinSum\)]],
  " and ",
  Cell[BoxData[
      \(EinsteinArray\)]],
  ". ",
  Cell[BoxData[
      \(ToArrayValues\)]],
  " in old notebooks should be changed to ",
  Cell[BoxData[
      \(ToArrayValues[]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "3) Added routines: ",
  Cell[BoxData[
      \(PermutationSymbolRules\)]],
  ", ",
  Cell[BoxData[
      \(UsePartialDChainRule\)]],
  ", ",
  Cell[BoxData[
      \(UseTotalDChainRule\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["1 Nov 2003", "Subsection"],

Cell[TextData[{
  "1) Usage of ",
  Cell[BoxData[
      \(IndexChange\)]],
  " and ",
  Cell[BoxData[
      \(SymmetrizeSlots\)]],
  " extended to allow single index cases to be entered without extra \
brackets."
}], "Text"],

Cell["\<\
2) Christoffel symbol calculating routines extended to allow the passing of a \
simplification routine to be applied to the elements.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["20 Nov 2003", "Subsection"],

Cell[TextData[{
  "1) ",
  Cell[BoxData[
      \(ParseTermIndices\)]],
  " fixed to handle ",
  Cell[BoxData[
      \(AbsoluteD\)]]
}], "Text"],

Cell[TextData[{
  "2) ",
  Cell[BoxData[
      \(UsePartialDChainRule\)]],
  " extended to higher order partials"
}], "Text"],

Cell[TextData[{
  "3) ",
  Cell[BoxData[
      \(ExpandAbsoluteD\)]],
  " now passes ",
  Cell[BoxData[
      \(TotalD\)]],
  " expressions through."
}], "Text"],

Cell[TextData[{
  "4) ",
  Cell[BoxData[
      \(MapLevelParts\)]],
  " and ",
  Cell[BoxData[
      \(DeclareZeroTensor\)]],
  " routines added"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["19 Dec 2003", "Subsection"],

Cell[TextData[{
  Cell[BoxData[
      \(PartialSum\)]],
  " and ",
  Cell[BoxData[
      \(PartialArray\)]],
  " added. Fix-ups to documentation"
}], "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
WindowToolbars->{},
WindowSize->{632, 602},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 46, 0, 76, "Title"],
Cell[1825, 55, 371, 16, 295, "Subsubtitle"],
Cell[2199, 73, 606, 12, 114, "Text"],
Cell[2808, 87, 227, 4, 74, "Text"],
Cell[3038, 93, 268, 6, 54, "Text"],

Cell[CellGroupData[{
Cell[3331, 103, 36, 0, 61, "Section"],
Cell[3370, 105, 229, 5, 54, "Text"],
Cell[3602, 112, 480, 16, 74, "Text"],
Cell[4085, 130, 1379, 38, 214, "Text"],
Cell[5467, 170, 648, 13, 134, "Text"],
Cell[6118, 185, 658, 11, 134, "Text"],
Cell[6779, 198, 425, 7, 94, "Text"],
Cell[7207, 207, 582, 11, 114, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7826, 223, 39, 0, 41, "Section"],
Cell[7868, 225, 316, 7, 114, "Text"],
Cell[8187, 234, 195, 6, 54, "Text"],
Cell[8385, 242, 73, 0, 34, "Text"],
Cell[8461, 244, 72, 1, 46, "Input"],
Cell[8536, 247, 176, 6, 34, "Text"],
Cell[8715, 255, 79, 1, 46, "Input"],
Cell[8797, 258, 268, 11, 54, "Text"],
Cell[9068, 271, 75, 1, 46, "Input"],
Cell[9146, 274, 220, 6, 54, "Text"],
Cell[9369, 282, 63, 1, 46, "Input"],
Cell[9435, 285, 124, 3, 34, "Text"],
Cell[9562, 290, 255, 6, 66, "Input"],
Cell[9820, 298, 152, 3, 54, "Text"],
Cell[9975, 303, 72, 1, 46, "Input"],
Cell[10050, 306, 54, 0, 34, "Text"],
Cell[10107, 308, 66, 1, 46, "Input"],
Cell[10176, 311, 555, 19, 94, "Text"],
Cell[10734, 332, 77, 1, 46, "Input"],
Cell[10814, 335, 218, 8, 54, "Text"],
Cell[11035, 345, 109, 2, 66, "Input"],
Cell[11147, 349, 110, 3, 34, "Text"],
Cell[11260, 354, 113, 2, 66, "Input"],
Cell[11376, 358, 780, 28, 114, "Text"],
Cell[12159, 388, 363, 6, 149, "Input"],
Cell[12525, 396, 126, 4, 34, "Text"],
Cell[12654, 402, 300, 5, 129, "Input"],
Cell[12957, 409, 61, 0, 34, "Text"],
Cell[13021, 411, 149, 3, 82, "Input"],
Cell[13173, 416, 33, 0, 34, "Text"],
Cell[13209, 418, 330, 5, 126, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13576, 428, 49, 0, 41, "Section"],
Cell[13628, 430, 165, 3, 54, "Text"],

Cell[CellGroupData[{
Cell[13818, 437, 33, 0, 49, "Subsection"],
Cell[13854, 439, 274, 9, 54, "Text"],
Cell[14131, 450, 392, 17, 74, "Text"],
Cell[14526, 469, 224, 11, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[14787, 485, 32, 0, 33, "Subsection"],
Cell[14822, 487, 224, 9, 54, "Text"],
Cell[15049, 498, 157, 3, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15243, 506, 33, 0, 33, "Subsection"],
Cell[15279, 508, 143, 7, 34, "Text"],
Cell[15425, 517, 125, 5, 34, "Text"],
Cell[15553, 524, 161, 8, 34, "Text"],
Cell[15717, 534, 157, 8, 34, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15911, 547, 33, 0, 33, "Subsection"],
Cell[15947, 549, 157, 7, 34, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

