(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7985,        256]*)
(*NotebookOutlinePosition[      8971,        290]*)
(*  CellTagsIndexPosition[      8897,        284]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["KroneckerAbsorb", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["KroneckerAbsorb",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox["\[Delta]",
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will perform all replacement operations of first order mixed tensors with \
labels \[Delta], assumed to be Kronecker deltas."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 In Tensorial all Kronecker symbols must have one Void in each slot just like \
all other indexed objects. Many texts use indices in both the up and down \
positions, taking advantage of the fact that Kroneckers must be even order \
with equal number of up and down indices.\
\>", "MathCaption"],

Cell["\<\
Labels other that \[Delta] can be used to represent the Kronecker.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FullKroneckerExpand",
    ButtonData:>{"FullKroneckerExpand"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialKroneckerExpand",
    ButtonData:>{"PartialKroneckerExpand"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ContractKroneckers",
    ButtonData:>{"ContractKroneckers"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MapLevelParts",
    ButtonData:>{"MapLevelParts"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare base indices and flavors.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
            SuperStar}};\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{x, 1}, {{\[Delta], \[Kappa], S}, 2}]\)], "Input",\

  CellLabel->"In[7]:="],

Cell[BoxData[{
    \(\[Delta]ud[i, r] \[Delta]ud[r, j]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[{
    \(\[Delta]ud[i, r] \[Delta]ud[r, j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[{
    \(\[Delta]ud[i, r] \[Delta]ud[r, s] \[Delta]ud[s, 
        j]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[{
    \(xu[j] \[Delta]ud[r, j]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[{
    \(\[Delta]ud[j, r] Sud[k, j]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[{
    \(\[Delta]ud[j, r] Sud[k, Cov[j]] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["\<\
The Kronecker can be represented by a label other than \[Delta].\
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]ud[j, r] Sud[k, j] // 
      ToFlavor[rocket]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Kappa]]\)}], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
We can even mix two different versions of Kronecker in an expression and then \
absorb them selectively...\
\>", "Text"],

Cell[BoxData[{
    \(\[Delta]ud[m, i] \[Kappa]ud[n, j] Suu[i, j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Kappa]]\)}], "Input",
  CellLabel->"In[22]:="],

Cell["Kronecker absorption with derivative expressions.", "Text"],

Cell[BoxData[{
    \(TotalD[xu[j], t] \[Delta]ud[r, j]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[{
    \(\[Delta]du[i, \[Nu]] \[Delta]ud[
        k, \[Mu]] \(PartialD[{x, \[Delta], g, \[CapitalGamma]}]\)[Sud[i, j], 
        xu[k]]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[27]:="],

Cell["\<\
If we expand before fully simplifying, we have to give the Kronecker values. \
This is a case where we might want to use Values instead of Rules. But \
students might want to see the steps. With Rules...\
\>", "Text"],

Cell[BoxData[
    \(SetTensorValueRules[\[Kappa]ud[i, j] // ToFlavor[red], \ 
      IdentityMatrix[NDim]]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[{
    \(\[Delta]ud[m, i] \[Kappa]ud[n, j] Suu[i, j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\), "\[IndentingNewLine]", 
    \(\(\(% // EinsteinSum[]\) // EinsteinArray[]\) // 
      MatrixForm\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[Kappa]] // MatrixForm\)}], "Input",
  CellLabel->"In[30]:="],

Cell["With Values...", "Text"],

Cell[BoxData[
    \(SetTensorValues[\[Kappa]ud[i, j] // ToFlavor[red], \ 
      IdentityMatrix[NDim]]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[{
    \(\[Delta]ud[m, i] \[Kappa]ud[n, j] Suu[i, j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\), "\[IndentingNewLine]", 
    \(\(\(% // EinsteinSum[]\) // EinsteinArray[]\) // MatrixForm\)}], "Input",\

  CellLabel->"In[35]:="],

Cell["Restore the initial state...", "Text"],

Cell[BoxData[{
    \(ClearTensorValues[\[Kappa]ud[i, j] // ToFlavor[red]]\), "\n", 
    \(ClearTensorShortcuts[{x, 1}, {{\[Delta], \[Kappa], S}, 2}]\)}], "Input",\

  CellLabel->"In[38]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[40]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{674, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 583, 22, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8726, 275}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 583, 22, 49, "Usage",
  CellTags->"Function?"],
Cell[2427, 80, 305, 5, 65, "MathCaption"],
Cell[2735, 87, 97, 2, 31, "MathCaption"],
Cell[2835, 91, 504, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3364, 113, 34, 0, 40, "ExampleSection"],
Cell[3401, 115, 96, 2, 29, "Input"],
Cell[3500, 119, 71, 0, 25, "Text"],
Cell[3574, 121, 357, 7, 109, "Input"],
Cell[3934, 130, 118, 3, 29, "Input"],
Cell[4055, 135, 156, 3, 49, "Input"],
Cell[4214, 140, 181, 4, 49, "Input"],
Cell[4398, 146, 183, 4, 49, "Input"],
Cell[4584, 152, 146, 3, 49, "Input"],
Cell[4733, 157, 150, 3, 49, "Input"],
Cell[4886, 162, 179, 4, 49, "Input"],
Cell[5068, 168, 88, 2, 25, "Text"],
Cell[5159, 172, 177, 4, 49, "Input"],
Cell[5339, 178, 130, 3, 25, "Text"],
Cell[5472, 183, 255, 5, 69, "Input"],
Cell[5730, 190, 65, 0, 25, "Text"],
Cell[5798, 192, 157, 3, 49, "Input"],
Cell[5958, 197, 249, 5, 49, "Input"],
Cell[6210, 204, 227, 4, 42, "Text"],
Cell[6440, 210, 143, 3, 29, "Input"],
Cell[6586, 215, 370, 7, 89, "Input"],
Cell[6959, 224, 30, 0, 25, "Text"],
Cell[6992, 226, 139, 3, 29, "Input"],
Cell[7134, 231, 286, 6, 69, "Input"],
Cell[7423, 239, 44, 0, 25, "Text"],
Cell[7470, 241, 189, 4, 49, "Input"],
Cell[7662, 247, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

