(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6677,        215]*)
(*NotebookOutlinePosition[      7663,        249]*)
(*  CellTagsIndexPosition[      7589,        243]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MapLevelParts", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["MapLevelParts",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(function, {topposition, levelpositions}\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will map the function onto the selected level positions in an \
expression."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 Levelpositions is an integer list of the selected parts. The function is \
applied to them as a group and they are replaced with a single new \
expression. Other parts not specified on the list are left unchanged.\
\>", "MathCaption"],

Cell["\<\
 MapLevelParts is useful when you wish to apply SimplifyTensorSum to just a \
selected set of terms in a sum. It is easier and more controlled to simplify \
such sums when you are not dealing with disparate terms. It is also useful in \
applying MetricSimplify or KroneckerAbsorb to a selected set of factors in a \
term.\
\>", "MathCaption"],

Cell[TextData[{
  " However, with TraditionalForm output, as the Tensorial style sheet has, \
the display order of terms is not always the same as the internal order. Add \
",
  Cell[BoxData[
      \(\(\(//\)\(StandardForm\)\)\)]],
  " to the output you will be operating on to get the internal order."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SimplifyTensorSum",
    ButtonData:>{"SimplifyTensorSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UpDownSwap",
    ButtonData:>{"UpDownSwap"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IndexChange",
    ButtonData:>{"IndexChange"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SymmetrizeSlots",
    ButtonData:>{"SymmetrizeSlots"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MetricSimplify",
    ButtonData:>{"MetricSimplify"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DummySimplify",
    ButtonData:>{"DummySimplify"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{\[Lambda], \[Kappa]}, 1}, {g, 2}]\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "The following is an example of using ",
  Cell[BoxData[
      \(MapLevelParts\)]],
  "."
}], "Text"],

Cell["\<\
For smooth functions the order of partial differentiation does not matter. It \
does matter for covariant differentiation. In general order independence is \
not true for covariant differentiation. For example, for a contravariant \
vector field...\
\>", "Text"],

Cell[BoxData[{
    \(Print["\<Covariant differentiation is not commutative\>"]\), "\
\[IndentingNewLine]", 
    \(CovariantD[\[Lambda]u[a], {b, c}] \[NotEqual] 
      CovariantD[\[Lambda]u[a], {c, b}]\), "\[IndentingNewLine]", 
    \(Print["\<Expand, rearrange and use symmetry on \[CapitalGamma]\>"]\), "\
\[IndentingNewLine]", 
    \(\(ExpandCovariantD[{x, \[Delta], g, \[CapitalGamma]}, {d, 
            e}] /@ %%;\)\), "\[IndentingNewLine]", 
    \(\(\(# - Part[%, 2] &\) /@ % // ExpandAll;\)\), "\[IndentingNewLine]", 
    \(% // SymmetrizeSlots[\[CapitalGamma], 
        3, {1, {2, 3}}]\), "\[IndentingNewLine]", 
    \(Print["\<Factor the first four terms, and use SimplifyTensorSum on the \
other terms\nFirst we factored the first four terms.\>"]\), "\
\[IndentingNewLine]", 
    \(%% // 
      MapLevelParts[Factor, \ {1, {1, 2, 3, 4}}]\), "\[IndentingNewLine]", 
    \(Print["\<Then we used SimplifyTensorSum on the last four terms, which \
reduced to 0.\>"]\), "\[IndentingNewLine]", 
    \(%% // MapLevelParts[SimplifyTensorSum, \ {1, {2, 3, 4, 5}}]\)}], "Input",\

  CellLabel->"In[3]:="],

Cell["In general the term in brackets will not be zero.", "Text"],

Cell[TextData[{
  "Sometimes when using ",
  Cell[BoxData[
      \(MetricSimplify\)]],
  ", or ",
  Cell[BoxData[
      \(KroneckerAbsorb\)]],
  ", it is ambiguous as to which factors are to be operated on. In the \
following the index on the ",
  Cell[BoxData[
      \(\[Kappa]\)]],
  " vector is lowered."
}], "Text"],

Cell[BoxData[{
    \(gdd[a, b] \[Kappa]u[a] \[Lambda]u[b]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[{
  "If we wish to lower the ",
  Cell[BoxData[
      \(\[Lambda]\)]],
  " index instead, we could use..."
}], "Text"],

Cell[BoxData[{
    \(gdd[a, b] \[Kappa]u[a] \[Lambda]u[b]\), "\[IndentingNewLine]", 
    \(% // MapLevelParts[MetricSimplify[g], {{1, 3}}]\)}], "Input",
  CellLabel->"In[15]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{670, 627},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 60, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1839, 56, 565, 22, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7418, 234}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1839, 56, 565, 22, 49, "Usage",
  CellTags->"Function?"],
Cell[2407, 80, 245, 4, 48, "MathCaption"],
Cell[2655, 86, 352, 6, 65, "MathCaption"],
Cell[3010, 94, 321, 7, 48, "MathCaption"],
Cell[3334, 103, 676, 26, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[4035, 133, 36, 0, 40, "ExampleSection"],
Cell[4074, 135, 96, 2, 29, "Input"],
Cell[4173, 139, 114, 2, 29, "Input"],
Cell[4290, 143, 119, 5, 25, "Text"],
Cell[4412, 150, 272, 5, 42, "Text"],
Cell[4687, 157, 1102, 21, 249, "Input"],
Cell[5792, 180, 65, 0, 25, "Text"],
Cell[5860, 182, 319, 12, 42, "Text"],
Cell[6182, 196, 152, 3, 49, "Input"],
Cell[6337, 201, 132, 5, 25, "Text"],
Cell[6472, 208, 177, 3, 49, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

