(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9909,        332]*)
(*NotebookOutlinePosition[     10896,        366]*)
(*  CellTagsIndexPosition[     10821,        360]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["MetricSimplify", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["MetricSimplify",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox["g",
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expression",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will raise or lower indices when products with the metric tensor g \
appear."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 g is the label of the metric tensor. The routine assumes that any second \
order tensor with the label g is a metric tensor. One could also use other \
labels to stand for the metric tensor, for example \[Eta] or h.\
\>", "MathCaption"],

Cell[TextData[{
  "Simplification occurs only if the two indices of ",
  Cell[BoxData[
      \(g\)]],
  " have the same flavor."
}], "MathCaption"],

Cell["\<\
 up/down and down/up metric tensors will act as Kroneckers, performing index \
substitution.\
\>", "MathCaption"],

Cell[TextData[{
  "The decision to use ",
  Cell[BoxData[
      \(MetricSimplify\)]],
  " may depend upon the particular tensor forms that have stored values. You \
may often wish to use ",
  Cell[BoxData[
      \(MetricSimplify\)]],
  " on only portions of an expression."
}], "MathCaption"],

Cell["\<\
If both indices of a metric tensor are dummy indices in an expression, then \
the lowest sort order index is used as the active dummy index in the \
simplification.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SetMetricValues",
    ButtonData:>{"SetMetricValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetMetricValueRules",
    ButtonData:>{"SetMetricValueRules"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EvaluateDotProducts",
    ButtonData:>{"EvaluateDotProducts"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["MapLevelParts",
    ButtonData:>{"MapLevelParts"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare base indices and flavors...", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
            SuperStar}};\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{A, x, y}, 1}, {{g, h, \[Eta], S}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], g, \[CapitalGamma]};\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell["Lowering indices...", "Text"],

Cell[BoxData[{
    \(gdd[i, j] xu[i]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[9]:="],

Cell["Raising indices....", "Text"],

Cell[BoxData[{
    \(guu[i, j] xd[j]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[11]:="],

Cell["Mixed up/down metric tensors act like Kroneckers.", "Text"],

Cell[BoxData[{
    \(gud[i, j] xu[j]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[{
    \(gdu[i, j] xu[i]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[15]:="],

Cell["The index flavors must match...", "Text"],

Cell[BoxData[{
    \(gdd[i, j] \((Sdu[m, i] // ToFlavor[red])\)\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[{
    \(gdd[i, j] Sdu[m, i] // ToFlavor[rocket]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[19]:="],

Cell["Both indices on the metric matrix must be the same flavor.", "Text"],

Cell[BoxData[{
    \(gdd[red@i, j] xu[j]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[21]:="],

Cell["Lowering a differentiated index.", "Text"],

Cell[BoxData[{
    \(gdd[i, j] Sdu[m, Cov[j]] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[23]:="],

Cell["MetricSimplify works on partial derivative expressions.", "Text"],

Cell[BoxData[{
    \(gdd[\[Alpha], p] 
        guu[\[Beta], q] \(PartialD[labs]\)[Au[p], {xu[q], xu[\[Beta]]}] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[25]:="],

Cell["An equation...", "Text"],

Cell[BoxData[{
    \(gdd[j, i] xu[i] \[Equal] gdd[i, j] yu[i] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[27]:="],

Cell["Double application...", "Text"],

Cell[BoxData[{
    \(guu[i, m]\ guu[j, n] xd[i] xd[j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[{
    \(guu[i, m] xd[i] yu[n] + guu[i, m]\ guu[j, n] xd[i] xd[j] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[31]:="],

Cell["The metric tensor does not have to be named g.", "Text"],

Cell[BoxData[{
    \(huu[i, m]\ huu[j, n] xd[i] xd[j]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[h]\)}], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
We could even have two versions of a metric tensor and simplify \
selectively.\
\>", "Text"],

Cell[BoxData[{
    \(huu[i, m]\ \[Eta]uu[j, n] xd[i] xd[j]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[h]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[\[Eta]]\)}], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
We can use rules to do partial metric simplifications. We exclude a factor we \
don't want in the simplification.\
\>", "Text"],

Cell[BoxData[{
    \(guu[i, m]\ guu[j, n] xd[i] yd[j]\), "\[IndentingNewLine]", 
    \(% /. a_.  xd[i] \[RuleDelayed] 
        xd[i] \(MetricSimplify[g]\)[a]\)}], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[{
    \(guu[i, m]\ guu[j, n] xd[i] yd[j]\), "\[IndentingNewLine]", 
    \(% /. a_.  guu[j, n] \[RuleDelayed] 
        guu[j, n] \(MetricSimplify[g]\)[a]\)}], "Input",
  CellLabel->"In[40]:="],

Cell[TextData[{
  "A better method is to use ",
  Cell[BoxData[
      \(MapLevelParts\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(guu[i, m]\ guu[j, n] xd[i] yd[j]\), "\[IndentingNewLine]", 
    \(% // MapLevelParts[MetricSimplify[g], {{1, 3}}]\)}], "Input",
  CellLabel->"In[42]:="],

Cell["\<\
The following is probably not the metric simplification that is desired. The \
desired simplification is ambiguous, but Tensorial uses the lowest sort order \
index as the dummy index and hence lowers the index on x.\
\>", "Text"],

Cell[BoxData[{
    \(gdd[i, j] xu[i] yu[j] - xu[i] yd[i]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\)}], "Input",
  CellLabel->"In[44]:="],

Cell["MapLevelParts will do the simplification we want.", "Text"],

Cell[BoxData[{
    \(gdd[i, j] xu[i] yu[j] - xu[i] yd[i]\), "\[IndentingNewLine]", 
    \(% // MapLevelParts[MetricSimplify[g], {1, {1, 3}}]\)}], "Input",
  CellLabel->"In[46]:="],

Cell["Or we could have done the following...", "Text"],

Cell[BoxData[{
    \(gdd[i, j] xu[i] yu[j] - xu[i] yd[i]\), "\[IndentingNewLine]", 
    \(% // MetricSimplify[g]\), "\[IndentingNewLine]", 
    \(MapAt[UpDownSwap[j], %, 1] // SimplifyTensorSum\)}], "Input",
  CellLabel->"In[48]:="],

Cell["Restore the settings...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{A, x, y}, 1}, {{g, h, \[Eta], S}, 2}]\)], "Input",\

  CellLabel->"In[51]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors, labs]\)}], "Input",
  CellLabel->"In[52]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 533, 22, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 10650, 351}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 533, 22, 32, "Usage",
  CellTags->"Function?"],
Cell[2376, 80, 247, 4, 48, "MathCaption"],
Cell[2626, 86, 147, 5, 31, "MathCaption"],
Cell[2776, 93, 123, 3, 31, "MathCaption"],
Cell[2902, 98, 292, 9, 48, "MathCaption"],
Cell[3197, 109, 195, 4, 48, "MathCaption"],
Cell[3395, 115, 492, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3912, 137, 34, 0, 40, "ExampleSection"],
Cell[3949, 139, 96, 2, 29, "Input"],
Cell[4048, 143, 73, 0, 25, "Text"],
Cell[4124, 145, 357, 7, 109, "Input"],
Cell[4484, 154, 208, 4, 49, "Input"],
Cell[4695, 160, 35, 0, 25, "Text"],
Cell[4733, 162, 130, 3, 49, "Input"],
Cell[4866, 167, 35, 0, 25, "Text"],
Cell[4904, 169, 131, 3, 49, "Input"],
Cell[5038, 174, 65, 0, 25, "Text"],
Cell[5106, 176, 131, 3, 49, "Input"],
Cell[5240, 181, 131, 3, 49, "Input"],
Cell[5374, 186, 47, 0, 25, "Text"],
Cell[5424, 188, 158, 3, 49, "Input"],
Cell[5585, 193, 155, 3, 49, "Input"],
Cell[5743, 198, 74, 0, 25, "Text"],
Cell[5820, 200, 135, 3, 49, "Input"],
Cell[5958, 205, 48, 0, 25, "Text"],
Cell[6009, 207, 157, 3, 49, "Input"],
Cell[6169, 212, 71, 0, 25, "Text"],
Cell[6243, 214, 229, 5, 49, "Input"],
Cell[6475, 221, 30, 0, 25, "Text"],
Cell[6508, 223, 180, 4, 49, "Input"],
Cell[6691, 229, 37, 0, 25, "Text"],
Cell[6731, 231, 172, 4, 49, "Input"],
Cell[6906, 237, 196, 4, 49, "Input"],
Cell[7105, 243, 62, 0, 25, "Text"],
Cell[7170, 245, 148, 3, 49, "Input"],
Cell[7321, 250, 102, 3, 25, "Text"],
Cell[7426, 255, 214, 4, 69, "Input"],
Cell[7643, 261, 137, 3, 25, "Text"],
Cell[7783, 266, 196, 4, 49, "Input"],
Cell[7982, 272, 204, 4, 49, "Input"],
Cell[8189, 278, 108, 5, 25, "Text"],
Cell[8300, 285, 173, 3, 49, "Input"],
Cell[8476, 290, 240, 4, 42, "Text"],
Cell[8719, 296, 151, 3, 49, "Input"],
Cell[8873, 301, 65, 0, 25, "Text"],
Cell[8941, 303, 179, 3, 49, "Input"],
Cell[9123, 308, 54, 0, 25, "Text"],
Cell[9180, 310, 232, 4, 69, "Input"],
Cell[9415, 316, 39, 0, 25, "Text"],
Cell[9457, 318, 120, 3, 29, "Input"],
Cell[9580, 323, 301, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

