(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5634,        188]*)
(*NotebookOutlinePosition[      6659,        224]*)
(*  CellTagsIndexPosition[      6585,        218]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["NonzeroValueRules", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"NonzeroValueRules", "[", "label", "]"}],
        "MR"]]],
  " gives only the rules for the label that have nonzero right hand sides.\n\
\[FilledSmallSquare] ",
  Cell[BoxData[
      StyleBox[
        RowBox[{"NonzeroValueRules", "[", 
          RowBox[{"label1", ",", "label2", ",", "..."}], "]"}],
        "MR"]]],
  " concatenates the nonzero rules for several labels."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
This is useful for viewing the values for tensors and objects that have many \
zero values.\
\>", "MathCaption"],

Cell["\<\
NonzeroValueRules should not be used for substitution as it will not \
substitute zero values!\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["SetTensorValueRules",
    ButtonData:>{"SetTensorValueRules"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetTensorValues",
    ButtonData:>{"SetTensorValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClearTensorValues",
    ButtonData:>{"ClearTensorValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Tensor",
    ButtonData:>{"Tensor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UseCoordinates",
    ButtonData:>{"UseCoordinates"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "We will set up the metric for a wormhole in general relativity and work in \
a red flavor. (From an excellent book ",
  StyleBox["Gravity",
    FontSlant->"Italic"],
  " by James B. Hartle.)"
}], "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{t, r, \[Theta], \[Phi]}]\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{x, 1}, {\[CapitalGamma], 3}]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[{
    \(cmetric = 
      DiagonalMatrix[{\(-1\), 1, 
          b\^2 + r\^2, \((b\^2 + r\^2)\) 
            Sin[\[Theta]]\^2}]\), "\[IndentingNewLine]", 
    \(metric = 
      cmetric // CoordinatesToTensors[{t, r, \[Theta], \[Phi]}, x, 
          red]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["Next we calculate and set rules for the Christoffel symbols.", "Text"],

Cell[BoxData[
    \(SetChristoffelValueRules[xu[red@i], \ 
      metric, \ \[CapitalGamma]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "Using ",
  Cell[BoxData[
      \(NonzeroValueRules\)]],
  " we can obtain a short list of the Christoffel symbols. ",
  Cell[BoxData[
      \(TensorValueRules\)]],
  " would have given us a much longer list."
}], "Text"],

Cell[BoxData[
    \(\(NonzeroValueRules[\[CapitalGamma]] // 
        UseCoordinates[{t, r, \[Theta], \[Phi]}, x, red]\) // 
      TableForm\)], "Input",
  CellLabel->"In[11]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[{
    \(\(ClearTensorValues /@ \(ToFlavor[
            red] /@ {\[CapitalGamma]udd[i, j, k], \[CapitalGamma]ddd[i, j, 
              k]}\);\)\), "\n", 
    \(ClearTensorShortcuts[{x, 1}, {\[CapitalGamma], 3}]\)}], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[{
    \(\(DeclareBaseIndices[oldindices];\)\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[oldflavors];\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors, labs]\)}], "Input",
  CellLabel->"In[14]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
Magnification->1,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 64, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1843, 56, 501, 15, 55, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6414, 209}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 64, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1843, 56, 501, 15, 55, "Usage",
  CellTags->"Function?"],
Cell[2347, 73, 122, 3, 31, "MathCaption"],
Cell[2472, 78, 125, 3, 31, "MathCaption"],
Cell[2600, 83, 580, 22, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[3205, 109, 34, 0, 40, "ExampleSection"],
Cell[3242, 111, 96, 2, 29, "Input"],
Cell[3341, 115, 34, 0, 25, "Text"],
Cell[3378, 117, 268, 5, 89, "Input"],
Cell[3649, 124, 222, 6, 42, "Text"],
Cell[3874, 132, 188, 3, 49, "Input"],
Cell[4065, 137, 302, 8, 50, "Input"],
Cell[4370, 147, 76, 0, 25, "Text"],
Cell[4449, 149, 129, 3, 29, "Input"],
Cell[4581, 154, 239, 8, 42, "Text"],
Cell[4823, 164, 177, 4, 29, "Input"],
Cell[5003, 170, 33, 0, 25, "Text"],
Cell[5039, 172, 260, 5, 49, "Input"],
Cell[5302, 179, 304, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

