(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10571,        366]*)
(*NotebookOutlinePosition[     11581,        401]*)
(*  CellTagsIndexPosition[     11506,        395]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PartialD", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["PartialD",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(tensor, i\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents the partial derivative of the tensor with respect to the \
coordinate of index i.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["PartialD",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(tensor, {i, j,  ... }\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents higher order derivatives.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["PartialD",
            "MR"], 
          StyleBox["[",
            "MR"], 
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\(x, \[Delta], g, \[CapitalGamma]\),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(tensor, difvar\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands the partial derivative of the tensor with respect to difvar using \
a coordinate vector x and the Kronecker delta, \[Delta].\n\
\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["PartialD",
            "MR"], 
          StyleBox["[",
            "MR"], 
          RowBox[{
            StyleBox["{",
              "MR"], 
            StyleBox[\(x, \[Delta], g, \[CapitalGamma]\),
              "TI"], 
            StyleBox["}",
              "TI"]}], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(tensor, {difvar1, \ difvar2, \[Ellipsis]}\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands the partial derivative with respect to a number of \
differentiation variables."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " A differentiation variable, difvar, can be a symbolic variable or an x \
coordinate vector, ",
  Cell[BoxData[
      \(xu[j]\)]],
  " (in shortcut notation)."
}], "MathCaption"],

Cell["\<\
 The partial derivative of a tensor is not itself a tensor. However, it is \
used along with the Christoffel symbols in calculating the covariant \
derivative, which is a proper tensor.\
\>", "MathCaption"],

Cell[TextData[{
  " In the expanded form of ",
  Cell[BoxData[
      \(PartialD\)]],
  " the extended list of labels ",
  Cell[BoxData[
      \({x, \[Delta], g, \[CapitalGamma]}\)]],
  ", for coordinate, Kronecker, metric and Christoffel labels, is given to be \
in conformity with similar usage with the other derivatives. Only ",
  Cell[BoxData[
      \(x\)]],
  " and ",
  Cell[BoxData[
      \(\[Delta]\)]],
  " are actually used with ",
  "PartialD",
  ". "
}], "MathCaption"],

Cell[TextData[{
  "When working in a notebook with a constant set of labels one can put ",
  Cell[BoxData[
      \(labs = {x, \[Delta], g, \[CapitalGamma]}\)]],
  "and then use ",
  Cell[BoxData[
      \(\(PartialD[labs]\)[tensor, var]\)]],
  " in the extended call, with similar usage for the other derivative \
routines."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["ExpandPartialD",
    ButtonData:>{"ExpandPartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["NondependentPartialD",
    ButtonData:>{"NondependentPartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CovariantD",
    ButtonData:>{"CovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AbsoluteD",
    ButtonData:>{"AbsoluteD"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[36]:="],

Cell["Save settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[37]:="],

Cell["Define the tensor shortcuts and derivative labels.", "Text"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{x, T}, 1}, {{S, T, \[Delta]}, 
        2}]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], g, \[CapitalGamma]};\)\)}], "Input",
  CellLabel->"In[41]:="],

Cell["\<\
Without information as to the coordinate, a partial derivative simply shows a \
comma before the differentiated index. In the FullForm, the index is wrapped \
with the Head Dif.\
\>", "Text"],

Cell[BoxData[{
    \(Td[i]\), "\[IndentingNewLine]", 
    \(PartialD[%, j]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[43]:="],

Cell["Higher order partial derivatives are supported.", "Text"],

Cell[BoxData[{
    \(Tu[i]\), "\[IndentingNewLine]", 
    \(PartialD[%, {m, n, p}]\)}], "Input",
  CellLabel->"In[46]:="],

Cell["The partial derivative of a symbol is zero.", "Text"],

Cell[BoxData[
    \(PartialD[a, i]\)], "Input",
  CellLabel->"In[48]:="],

Cell[TextData[{
  Cell[BoxData[
      \(PartialD\)]],
  " obeys the linear and Liebnizian rules of differentiation."
}], "Text"],

Cell[BoxData[{
    \(a\ xu[i] + b\ Tu[i]\), "\[IndentingNewLine]", 
    \(PartialD[%, j]\)}], "Input",
  CellLabel->"In[49]:="],

Cell["\<\
For flavored expressions the intended flavor must also be on the indices.\
\>", "Text"],

Cell[BoxData[{
    \(a\ xu[i] Tu[j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(PartialD[%, red@k]\)}], "Input",
  CellLabel->"In[51]:="],

Cell[TextData[{
  "In the extended form of ",
  Cell[BoxData[
      \(PartialD\)]],
  ", using the derivative labels, the coordinate vector itself, rather than \
just the index must be given.  The expression is stored internally with an ",
  Cell[BoxData[
      \(PartialD[labs]\)]],
  " header, but is formatted as a partial derivative."
}], "Text"],

Cell[BoxData[{
    \(Td[i]\), "\n", 
    \(\(PartialD[labs]\)[%, xu[j]]\), "\[IndentingNewLine]", 
    \(% // FullForm\)}], "Input",
  CellLabel->"In[53]:="],

Cell["Derivatives of the coordinate give the Kronecker delta.", "Text"],

Cell[BoxData[{
    \(xu[i]\), "\[IndentingNewLine]", 
    \(\(PartialD[labs]\)[%, xu[j]]\)}], "Input",
  CellLabel->"In[56]:="],

Cell["To obtain a Kronecker the flavor of the indices must match.", "Text"],

Cell[BoxData[{
    \(xu[i]\), "\[IndentingNewLine]", 
    \(\(PartialD[labs]\)[%, xu[red@j]]\)}], "Input",
  CellLabel->"In[58]:="],

Cell["\<\
Partial derivatives may also be taken with respect to symbolic variables.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i]\), "\[IndentingNewLine]", 
    \(\(PartialD[labs]\)[%, v]\)}], "Input",
  CellLabel->"In[60]:="],

Cell["\<\
Partial derivatives may also be taken with respect to a mixture of \
coordinates and variables.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i]\), "\[IndentingNewLine]", 
    \(\(PartialD[labs]\)[%, {xu[j], xu[k], v}]\)}], "Input",
  CellLabel->"In[62]:="],

Cell["Derivatives may be taken sequentially.", "Text"],

Cell[BoxData[
    \(FoldList[PartialD[labs], 
      Sud[m, n] // ToFlavor[red], {xu[i], xu[j], xu[k]} // 
        ToFlavor[red]]\)], "Input",
  CellLabel->"In[64]:="],

Cell["\<\
Here we calculate the transformation matrix between Cartesian (red) and polar \
(plain) coordinates in the plane.\
\>", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{1, 2}]\), "\[IndentingNewLine]", 
    \(SetTensorValueRules[xu[i], {r, \[Phi]}]\), "\[IndentingNewLine]", 
    \(SetTensorValueRules[
      xu[red@i], {r\ Cos[\[Phi]], r\ Sin[\[Phi]]}]\)}], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[{
    \(xu[red@i]\), "\[IndentingNewLine]", 
    \(\(PartialD[labs]\)[%, xu[j]]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[x]\), "\[IndentingNewLine]", 
    \(% /. {Cos[\[Phi]] \[Rule] x/\@\(x\^2 + y\^2\), 
        Sin[\[Phi]] \[Rule] y/\@\(x\^2 + y\^2\), 
        r \[Rule] \@\(x\^2 + y\^2\)}\)}], "Input",
  CellLabel->"In[68]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, T}, 1}, {{S, T, \[Delta]}, 2}]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[{
    \(\(DeclareBaseIndices[oldindices];\)\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[oldflavors];\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors, labs]\)}], "Input",
  CellLabel->"In[74]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 55, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1834, 56, 2034, 75, 135, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 11333, 386}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1834, 56, 2034, 75, 135, "Usage",
  CellTags->"Function?"],
Cell[3871, 133, 197, 6, 31, "MathCaption"],
Cell[4071, 141, 216, 4, 48, "MathCaption"],
Cell[4290, 147, 481, 17, 65, "MathCaption"],
Cell[4774, 166, 342, 9, 48, "MathCaption"],
Cell[5119, 177, 556, 22, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5700, 203, 34, 0, 40, "ExampleSection"],
Cell[5737, 205, 97, 2, 29, "Input"],
Cell[5837, 209, 30, 0, 25, "Text"],
Cell[5870, 211, 269, 5, 89, "Input"],
Cell[6142, 218, 66, 0, 25, "Text"],
Cell[6211, 220, 205, 4, 49, "Input"],
Cell[6419, 226, 201, 4, 42, "Text"],
Cell[6623, 232, 160, 4, 69, "Input"],
Cell[6786, 238, 63, 0, 25, "Text"],
Cell[6852, 240, 121, 3, 49, "Input"],
Cell[6976, 245, 59, 0, 25, "Text"],
Cell[7038, 247, 72, 2, 29, "Input"],
Cell[7113, 251, 128, 4, 25, "Text"],
Cell[7244, 257, 127, 3, 49, "Input"],
Cell[7374, 262, 97, 2, 25, "Text"],
Cell[7474, 266, 143, 3, 49, "Input"],
Cell[7620, 271, 350, 9, 42, "Text"],
Cell[7973, 282, 157, 4, 69, "Input"],
Cell[8133, 288, 71, 0, 25, "Text"],
Cell[8207, 290, 127, 3, 49, "Input"],
Cell[8337, 295, 75, 0, 25, "Text"],
Cell[8415, 297, 131, 3, 49, "Input"],
Cell[8549, 302, 97, 2, 25, "Text"],
Cell[8649, 306, 123, 3, 49, "Input"],
Cell[8775, 311, 119, 3, 25, "Text"],
Cell[8897, 316, 139, 3, 49, "Input"],
Cell[9039, 321, 54, 0, 25, "Text"],
Cell[9096, 323, 166, 4, 49, "Input"],
Cell[9265, 329, 137, 3, 25, "Text"],
Cell[9405, 334, 264, 5, 69, "Input"],
Cell[9672, 341, 411, 8, 115, "Input"],
Cell[10086, 351, 33, 0, 25, "Text"],
Cell[10122, 353, 114, 2, 29, "Input"],
Cell[10239, 357, 304, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

