(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6188,        202]*)
(*NotebookOutlinePosition[      7174,        236]*)
(*  CellTagsIndexPosition[      7100,        230]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PartialSum", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["PartialSum",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(baseindex, newindices\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will expand the dummy indices of a tensor expression into components that \
have one or more baseindex indices and an unexpanded remainder. Symbolic \
indices are replaced with newindices."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 The newindices list of symbols is used to replace the existing dummy index \
symbols. Greek indices might be replaced with Latin indices to indicate a \
restricted further expansion. But it is up to the user to actually used a \
restriced expansion when further expansions are perform.\
\>", "MathCaption"],

Cell["\<\
Any flavor must be on the newindices but not on the baseindex.\
\>", "MathCaption"],

Cell["PartialSum is mapped over arrays, equations and sums.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["PartialArray",
    ButtonData:>{"PartialArray"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EinsteinSum",
    ButtonData:>{"EinsteinSum"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["EinsteinArray",
    ButtonData:>{"EinsteinArray"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SumExpansion",
    ButtonData:>{"SumExpansion"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save the settings and declare base indices and flavors.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{0, 1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[{red, Red}];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{dx, \[Lambda]}, 1}, {{g, T}, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["The following expands a contracted tensor on the 0 index.", "Text"],

Cell[BoxData[{
    \(Tud[\[Mu], \[Mu]]\), "\[IndentingNewLine]", 
    \(% // PartialSum[0, {i}]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The flavors should be in the new indices but not on the baseindex.\
\>", "Text"],

Cell[BoxData[{
    \(Tud[\[Mu], \[Mu]] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // PartialSum[0, {red@i}]\)}], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
The following first does an array expansion of a tensor expression on the 0 \
index, then does a sum expansion on the 0 index and then does a complete \
expansion.\
\>", "Text"],

Cell[BoxData[{
    \(Tuu[\[Mu], \[Nu]] \[Lambda]d[\[Nu]] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // PartialArray[0, {red@i}]\), "\[IndentingNewLine]", 
    \(% // PartialSum[0, {red@j}]\), "\[IndentingNewLine]", 
    \(ToArrayValues[{1, 2, 3}] /@ %\)}], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
The following expands the metric line element into temporal and spatial \
parts.\
\>", "Text"],

Cell[BoxData[{
    \(gdd[\[Mu], \[Nu]] dxu[\[Mu]] dxu[\[Nu]]\), "\[IndentingNewLine]", 
    \(% // PartialSum[0, {i, j}]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
The new indices must be sufficient to replace the old dummy indices after \
removing any conflicts with free indices.\
\>", "Text"],

Cell[BoxData[{
    \(gdd[\[Mu], \[Nu]] Tuu[i, \[Mu]] \[Lambda]u[\[Nu]] // 
      ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // PartialSum[0, red /@ {i, j}]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["Restore the initial values...", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{dx, \[Lambda]}, 1}, {{g, T}, 2}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[21]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 57, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1836, 56, 657, 23, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6929, 221}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 57, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1836, 56, 657, 23, 49, "Usage",
  CellTags->"Function?"],
Cell[2496, 81, 317, 5, 65, "MathCaption"],
Cell[2816, 88, 93, 2, 31, "MathCaption"],
Cell[2912, 92, 76, 0, 31, "MathCaption"],
Cell[2991, 94, 456, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3472, 116, 34, 0, 40, "ExampleSection"],
Cell[3509, 118, 96, 2, 29, "Input"],
Cell[3608, 122, 71, 0, 25, "Text"],
Cell[3682, 124, 322, 6, 109, "Input"],
Cell[4007, 132, 113, 2, 29, "Input"],
Cell[4123, 136, 73, 0, 25, "Text"],
Cell[4199, 138, 133, 3, 49, "Input"],
Cell[4335, 143, 90, 2, 25, "Text"],
Cell[4428, 147, 155, 3, 49, "Input"],
Cell[4586, 152, 187, 4, 42, "Text"],
Cell[4776, 158, 306, 6, 89, "Input"],
Cell[5085, 166, 104, 3, 25, "Text"],
Cell[5192, 171, 159, 3, 49, "Input"],
Cell[5354, 176, 141, 3, 25, "Text"],
Cell[5498, 181, 200, 4, 49, "Input"],
Cell[5701, 187, 45, 0, 25, "Text"],
Cell[5749, 189, 113, 2, 29, "Input"],
Cell[5865, 193, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

