(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6118,        200]*)
(*NotebookOutlinePosition[      7104,        234]*)
(*  CellTagsIndexPosition[      7030,        228]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["PermutationSymbolRules", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["PermutationSymbolRules",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox["\[Epsilon]",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " creates a set of rules that will substitute values for a permutation \
pseudotensor symbol with label ",
  Cell[BoxData[
      \(\[Epsilon]\)]],
  "."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
 For substitution the indices must be all up or all down, must be base \
indices and must all be in the same flavor.\
\>", "MathCaption"],

Cell[TextData[{
  " A symbol with the indices in the declared order of ",
  Cell[BoxData[
      \(BaseIndices\)]],
  " will have a value of ",
  Cell[BoxData[
      \(1\)]],
  "."
}], "MathCaption"],

Cell["\<\
An alternative is to set the values to the PermutationPseudotensor.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["FullKroneckerExpand",
    ButtonData:>{"FullKroneckerExpand"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialKroneckerExpand",
    ButtonData:>{"PartialKroneckerExpand"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PermutationPseudotensor",
    ButtonData:>{"PermutationPseudotensor"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save settings.", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(oldindices = BaseIndices;\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[{1, 2, 3}]\), "\n", 
    \(DeclareIndexFlavor[{red, Red}]\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[\[Epsilon], 3]\)}], "Input",
  CellLabel->"In[4]:="],

Cell[BoxData[{
    \(\[Epsilon]ddd[2, 1, 3]\), "\[IndentingNewLine]", 
    \(% /. PermutationSymbolRule[\[Epsilon]]\)}], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
The following shows results for various cases. Notice the cases that don't \
substitute.\
\>", "Text"],

Cell[BoxData[
    \(MapThread[{#, # /. 
            PermutationSymbolRule[\[Epsilon]]} &, {{\[Epsilon]ddd[a, c, 
            b], \[Epsilon]uuu[a, b, c] // ToFlavor[red], \[Epsilon]ddd[2, 3, 
            1], \[Epsilon]ddd[2, 3, 1] // ToFlavor[red], \[Epsilon]ddd[red@2, 
            3, 1], \[Epsilon]ddd[1, 3, 2], \[Epsilon]ddd[1, 2, 
            2], \[Epsilon]dud[1, 3, 2]}}]\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
An expansion of the array is the same as the PermutationPseudotensor.\
\>", "Text"],

Cell[BoxData[{
    \(\[Epsilon]ddd[i, j, k]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues[]\), "\[IndentingNewLine]", 
    \(% /. PermutationSymbolRule[\[Epsilon]]\), "\[IndentingNewLine]", 
    \(% == PermutationPseudotensor[3]\)}], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "Here is a case of base indices ",
  Cell[BoxData[
      \({q, p, r}\)]],
  " that are not in the natural sort order."
}], "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{q, p, r}]\), "\[IndentingNewLine]", 
    \(MapThread[{#, # /. 
            PermutationSymbolRule[\[Epsilon]]} &, {{\[Epsilon]ddd[a, c, 
            b], \[Epsilon]uuu[a, b, c] // ToFlavor[red], \[Epsilon]ddd[q, p, 
            r], \[Epsilon]ddd[p, r, q] // ToFlavor[red], \[Epsilon]ddd[red@p, 
            r, q], \[Epsilon]ddd[p, q, r], \[Epsilon]ddd[p, r, 
            r], \[Epsilon]dud[p, q, r]}}]\)}], "Input",
  CellLabel->"In[14]:="],

Cell["It is still equal to the pseudotensor.", "Text"],

Cell[BoxData[{
    \(\[Epsilon]ddd[i, j, k]\), "\[IndentingNewLine]", 
    \(% // ToArrayValues[]\), "\[IndentingNewLine]", 
    \(% /. PermutationSymbolRule[\[Epsilon]]\), "\[IndentingNewLine]", 
    \(% == PermutationPseudotensor[3]\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\)}], "Input",
  CellLabel->"In[16]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\n", 
    \(DeclareIndexFlavor[oldflavors]; \), "\n", 
    \(ClearTensorShortcuts[\[Epsilon], 3]\), "\n", 
    \(Clear[oldflavors, oldindices]\)}], "Input",
  CellLabel->"In[21]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{674, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 69, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1848, 56, 459, 18, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6859, 219}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 69, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1848, 56, 459, 18, 49, "Usage",
  CellTags->"Function?"],
Cell[2310, 76, 147, 3, 31, "MathCaption"],
Cell[2460, 81, 198, 8, 31, "MathCaption"],
Cell[2661, 91, 98, 2, 31, "MathCaption"],
Cell[2762, 95, 410, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3197, 113, 36, 0, 40, "ExampleSection"],
Cell[3236, 115, 96, 2, 29, "Input"],
Cell[3335, 119, 30, 0, 25, "Text"],
Cell[3368, 121, 152, 3, 49, "Input"],
Cell[3523, 126, 205, 4, 69, "Input"],
Cell[3731, 132, 153, 3, 49, "Input"],
Cell[3887, 137, 112, 3, 25, "Text"],
Cell[4002, 142, 412, 7, 69, "Input"],
Cell[4417, 151, 93, 2, 25, "Text"],
Cell[4513, 155, 273, 5, 89, "Input"],
Cell[4789, 162, 148, 5, 25, "Text"],
Cell[4940, 169, 478, 8, 89, "Input"],
Cell[5421, 179, 54, 0, 25, "Text"],
Cell[5478, 181, 336, 6, 109, "Input"],
Cell[5817, 189, 33, 0, 25, "Text"],
Cell[5853, 191, 237, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

