(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4673,        169]*)
(*NotebookOutlinePosition[      5659,        203]*)
(*  CellTagsIndexPosition[      5585,        197]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["SymmetrizeSlots", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["SymmetrizeSlots",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(label, order, symmetries\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " will put indices in standard sort order for all tensors of the given \
label and order in expr."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  " The symmetries are given by a list of symmetry specifications, ",
  Cell[BoxData[
      \({symm1, symm2,  ... }\)]],
  "."
}], "MathCaption"],

Cell[TextData[{
  "Each symmetry specification is of the form ",
  Cell[BoxData[
      \({\(-1\) | 1, {n1, n2,  ... }}\)]],
  " where ",
  Cell[BoxData[
      \(\(-1\)\)]],
  " is used for antisymmetry and 1 for symmetry. n1, n2 etc., are the slot \
numbers involved in the symmetry."
}], "MathCaption"],

Cell[TextData[{
  "By putting indices in standard sort order with multiple terms, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will perform simplifications."
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(IndexChange\)]],
  " can be used to impose symmetries in a multi-tensor term."
}], "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Symmetric",
    ButtonData:>{"Symmetric"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["AntiSymmetric",
    ButtonData:>{"AntiSymmetric"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IndexChange",
    ButtonData:>{"IndexChange"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[T, 2]\)], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  "Here we simplify a sum when ",
  Cell[BoxData[
      \(T\)]],
  " is symmetric or antisymmetric in its indices."
}], "Text"],

Cell[BoxData[{
    \(Tuu[i, j] + Tuu[j, i]\), "\[IndentingNewLine]", 
    \(% // SymmetrizeSlots[T, 2, {{1, {1, 2}}}]\), "\[IndentingNewLine]", 
    \(%% // SymmetrizeSlots[T, 2, {{\(-1\), {1, 2}}}]\)}], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
Because this involves only a single symmetry it could also be entered without \
the extra brakets.\
\>", "Text"],

Cell[BoxData[{
    \(Tuu[i, j] + Tuu[j, i]\), "\[IndentingNewLine]", 
    \(% // SymmetrizeSlots[T, 2, {1, {1, 2}}]\), "\[IndentingNewLine]", 
    \(%% // SymmetrizeSlots[T, 2, {\(-1\), {1, 2}}]\)}], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(ClearTensorShortcuts[T, 2]\)], "Input",
  CellLabel->"In[9]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{674, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 62, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1841, 56, 572, 22, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 5414, 188}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 62, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1841, 56, 572, 22, 49, "Usage",
  CellTags->"Function?"],
Cell[2416, 80, 161, 5, 31, "MathCaption"],
Cell[2580, 87, 303, 9, 48, "MathCaption"],
Cell[2886, 98, 190, 5, 31, "MathCaption"],
Cell[3079, 105, 137, 4, 31, "MathCaption"],
Cell[3219, 111, 348, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3592, 129, 36, 0, 40, "ExampleSection"],
Cell[3631, 131, 96, 2, 29, "Input"],
Cell[3730, 135, 84, 2, 29, "Input"],
Cell[3817, 139, 143, 5, 25, "Text"],
Cell[3963, 146, 236, 4, 69, "Input"],
Cell[4202, 152, 122, 3, 25, "Text"],
Cell[4327, 157, 232, 4, 69, "Input"],
Cell[4562, 163, 83, 2, 29, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

