(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5748,        206]*)
(*NotebookOutlinePosition[      6734,        240]*)
(*  CellTagsIndexPosition[      6660,        234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Tensor", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Tensor",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox[\(a, upindices, downindices\),
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents a tensor or indexed object with label a and the given up and \
down indices\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        StyleBox["Tensor",
          "MR"], 
        StyleBox["[",
          "MR"], 
        StyleBox["\[Phi]",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " represents a scalar tensor"
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
Tensorial uses the heading Tensor even though the objects in question may not \
be true tensors, for example coordinates or Christoffel symbols or \
transformation matrices. We debated using the heading IndexedObject but \
decided to stay with Tensor. \
\>", "MathCaption"],

Cell["The up and down indices are specified in lists.", "MathCaption"],

Cell["The number of up and down indices must be equal. ", "MathCaption"],

Cell[TextData[{
  "Missing indices are specified by the symbol ",
  Cell[BoxData[
      \(Void\)]],
  ". Each index slot (up/down pair) must have one index and one Void."
}], "MathCaption"],

Cell[TextData[{
  Cell[BoxData[
      \(Dif[i]\)]],
  " is used to enter a partial derivative index. ",
  Cell[BoxData[
      \(Cov[i]\)]],
  " is used to enter a covariant derivative index. The output format of \
partial and covariant indices can be specified with ",
  Cell[BoxData[
      \(SetDerivativeSymbols\)]],
  "."
}], "MathCaption"],

Cell["\<\
Indices can have flavors corresponding to different coordinate systems or \
reference frames.\
\>", "MathCaption"],

Cell["\<\
Tensors can be more easily entered by defining and using tensor shortcuts. In \
normal use one might never use or see the Tensor heading.\
\>", "MathCaption"],

Cell["\<\
 Tensors are formatted on output and cannot be copied or pasted.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["Void",
    ButtonData:>{"Void"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Dif",
    ButtonData:>{"Dif"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["Cov",
    ButtonData:>{"Cov"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetDerivativeSymbols",
    ButtonData:>{"SetDerivativeSymbols"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DefineTensorShortcuts",
    ButtonData:>{"DefineTensorShortcuts"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["SetTensorValues",
    ButtonData:>{"SetTensorValues"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeclareBaseIndices",
    ButtonData:>{"DeclareBaseIndices"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeclareIndexFlavor",
    ButtonData:>{"DeclareIndexFlavor"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["This is a simple contravariant tensor.", "Text"],

Cell[BoxData[
    \(Tensor[R, {i}, {Void}]\)], "Input",
  CellLabel->"In[2]:="],

Cell["A more complex tensor is...", "Text"],

Cell[BoxData[
    \(Tensor[T, {Void, Void, Void}, {i, j, k}]\)], "Input",
  CellLabel->"In[3]:="],

Cell["A partial derivative of a single tensor can be entered as...", "Text"],

Cell[BoxData[
    \(Tensor[T, {i, Void}, {Void, Dif[n]}]\)], "Input",
  CellLabel->"In[4]:="],

Cell["\<\
A comma is displayed for each partial derivative index.  A covariant \
derivative of a single tensor can be entered as...\
\>", "Text"],

Cell[BoxData[
    \(Tensor[
      T, {i, j\ , Void, Void, Void}, {Void, Void, k, Cov[m], 
        Cov[n]}]\)], "Input",
  CellLabel->"In[5]:="],

Cell["A semi-colon is displayed for each covariant index.", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 53, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1832, 56, 657, 26, 55, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6489, 225}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 53, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1832, 56, 657, 26, 55, "Usage",
  CellTags->"Function?"],
Cell[2492, 84, 283, 5, 65, "MathCaption"],
Cell[2778, 91, 70, 0, 31, "MathCaption"],
Cell[2851, 93, 72, 0, 31, "MathCaption"],
Cell[2926, 95, 189, 5, 31, "MathCaption"],
Cell[3118, 102, 343, 11, 48, "MathCaption"],
Cell[3464, 115, 124, 3, 31, "MathCaption"],
Cell[3591, 120, 168, 3, 48, "MathCaption"],
Cell[3762, 125, 95, 2, 31, "MathCaption"],
Cell[3860, 129, 876, 34, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[4761, 167, 36, 0, 40, "ExampleSection"],
Cell[4800, 169, 96, 2, 29, "Input"],
Cell[4899, 173, 54, 0, 25, "Text"],
Cell[4956, 175, 79, 2, 29, "Input"],
Cell[5038, 179, 43, 0, 25, "Text"],
Cell[5084, 181, 97, 2, 29, "Input"],
Cell[5184, 185, 76, 0, 25, "Text"],
Cell[5263, 187, 93, 2, 29, "Input"],
Cell[5359, 191, 145, 3, 25, "Text"],
Cell[5507, 196, 143, 4, 29, "Input"],
Cell[5653, 202, 67, 0, 25, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

