(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6418,        211]*)
(*NotebookOutlinePosition[      7404,        245]*)
(*  CellTagsIndexPosition[      7330,        239]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ToFlavor", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["ToFlavor",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[
            RowBox[{"newflavor", ",", 
              RowBox[{"oldflavor", ":", "Identity"}]}],
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "MR"], 
        StyleBox["]",
          "MR"]}]]],
  "will change all indices in expr in the old flavor to the new flavor."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
The second argument is optional. Identity corresponds to plain unflavored \
indices. Identity may also be used as the newflavor.\
\>", "MathCaption"],

Cell[TextData[{
  "As an alternative, flavors can be directly entered in a tensor. For \
example ",
  Cell[BoxData[
      RowBox[{"Sud", "[", 
        RowBox[{
          RowBox[{"red", "@", "i"}], ",", 
          RowBox[{"red", "@", "j"}]}], "]"}]]],
  " but ",
  Cell[BoxData["ToFlavor"]],
  " checks that newflavor is a current flavor and issues an error message if \
not."
}], "MathCaption"],

Cell["\<\
For a transformation matrix, which connects two coordinate systems, you will \
have to directly enter the flavors.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["IndexFlavors",
    ButtonData:>{"IndexFlavors"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeclareIndexFlavor",
    ButtonData:>{"DeclareIndexFlavor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ClearIndexFlavor",
    ButtonData:>{"ClearIndexFlavor"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["IndexFlavorQ",
    ButtonData:>{"IndexFlavorQ"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["The following saves the current state.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell["\<\
This declares new base indices, flavors and some tensor shortcuts...\
\>", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[{red, Red}, {green, Cerulean}, {rocket, 
          SuperStar}];\)\), "\[IndentingNewLine]", 
    \(DefineTensorShortcuts[{x, 1}, {S, 2}]\)}], "Input",
  CellLabel->"In[5]:="],

Cell["Here is an expression and calculation with plain indices.", "Text"],

Cell[BoxData[{
    \(Sud[i, j] xu[j]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[8]:="],

Cell["This does the same calculation using red indices...", "Text"],

Cell[BoxData[{
    \(Sud[i, j] xu[j] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[11]:="],

Cell["And this does it in the rocket frame...", "Text"],

Cell[BoxData[{
    \(Sud[i, j] xu[j] // ToFlavor[rocket]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\(% // EinsteinArray[]\) // TableForm\)}], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
Here we switch between various flavors, ending with an error.\
\>", "Text"],

Cell[BoxData[{
    \(Sud[i, j] xu[j]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[green, red]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[rocket, green]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[Identity, rocket]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[blue]\)}], "Input",
  CellLabel->"In[17]:="],

Cell["Applying the same flavor twice leaves the flavor unchanged.", "Text"],

Cell[BoxData[{
    \(PartialD[Suu[i, j], k] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // ToFlavor[red, red]\)}], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(ClearTensorShortcuts[{x, 1}, {S, 2}]\)], "Input",
  CellLabel->"In[25]:="],

Cell["This resets to the original state.", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor[IndexFlavors];\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[26]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 55, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1834, 56, 603, 23, 32, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7159, 230}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1834, 56, 603, 23, 32, "Usage",
  CellTags->"Function?"],
Cell[2440, 81, 159, 3, 48, "MathCaption"],
Cell[2602, 86, 394, 12, 48, "MathCaption"],
Cell[2999, 100, 145, 3, 31, "MathCaption"],
Cell[3147, 105, 476, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3648, 127, 36, 0, 40, "ExampleSection"],
Cell[3687, 129, 96, 2, 29, "Input"],
Cell[3786, 133, 54, 0, 25, "Text"],
Cell[3843, 135, 187, 4, 69, "Input"],
Cell[4033, 141, 92, 2, 25, "Text"],
Cell[4128, 145, 279, 5, 69, "Input"],
Cell[4410, 152, 73, 0, 25, "Text"],
Cell[4486, 154, 197, 4, 69, "Input"],
Cell[4686, 160, 67, 0, 25, "Text"],
Cell[4756, 162, 215, 4, 69, "Input"],
Cell[4974, 168, 55, 0, 25, "Text"],
Cell[5032, 170, 218, 4, 69, "Input"],
Cell[5253, 176, 85, 2, 25, "Text"],
Cell[5341, 180, 366, 7, 129, "Input"],
Cell[5710, 189, 75, 0, 25, "Text"],
Cell[5788, 191, 156, 3, 49, "Input"],
Cell[5947, 196, 94, 2, 29, "Input"],
Cell[6044, 200, 50, 0, 25, "Text"],
Cell[6097, 202, 293, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

