(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7269,        239]*)
(*NotebookOutlinePosition[      8256,        273]*)
(*  CellTagsIndexPosition[      8182,        267]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["UseCoordinates", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["UseCoordinates",
            "MR"], 
          StyleBox["[",
            "MR"], 
          
          StyleBox[\({r, \[Theta], \[Phi] ... }, coord : x, 
            flavor : Identity\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " replaces the coordinate tensor components in expr by the list of  \
symbols. The optional arguments coord and flavor give the coordinate label, \
if not x, and the index flavor, if not plain.\n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["UseCoordinates",
            "MR"], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(coord : x, flavor : Identity\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " uses the index symbols established with ",
  Cell[BoxData[
      \(DeclareBaseIndices\)]],
  ", in which case they should be symbols and not integers."
}], "Usage",
  CellTags->"Function?"],

Cell["\<\
UseCoordinates is for the purposes of obtaining a final expression in terms \
of familiar variable symbols. The resulting output expression is no longer \
suitable for general Tensorial operations\
\>", "MathCaption"],

Cell["\<\
Another and often preferable method is to set tensor values for the \
coordinate vectors and then substitute them.\
\>", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["CoordinatesToTensors",
    ButtonData:>{"CoordinatesToTensors"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["DeclareBaseIndices",
    ButtonData:>{"DeclareBaseIndices"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save settings", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\n", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareBaseIndices[{1, 2, 3}]\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ {{red, Red}, {rocket, 
            SuperStar}};\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{{x, y, dx}, 1}, {{g, \[Eta]}, 2}]\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
Here is a simple case of a coordinate vector being replace by coordinate \
symbols.\
\>", "Text"],

Cell[BoxData[{
    \(xu[i]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% // UseCoordinates[{x, y, z}]\)}], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
For flavored indices, and for coordinate symbols other than x, we have to \
include the optional arguments.\
\>", "Text"],

Cell[BoxData[{
    \(yu[i] // ToFlavor[red]\), "\[IndentingNewLine]", 
    \(% // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% // UseCoordinates[{x, y, z}, y, red]\)}], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
If we have set symbols for the base indices, then we can use them directly.\
\>", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{x, y, z}]\), "\[IndentingNewLine]", 
    \(xu[i] // EinsteinArray[]\), "\[IndentingNewLine]", 
    \(% // UseCoordinates[]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[TextData[{
  "Here is a line element in spherical coordinates. The index symbols are \
specified as ",
  Cell[BoxData[
      \({r, \[Theta], \[Phi]}\)]],
  "."
}], "Text"],

Cell[BoxData[{\(DeclareBaseIndices[{r, \[Theta], \[Phi]}]\), "\n", 
    RowBox[{
      RowBox[{"metric", "=", 
        RowBox[{"(", GridBox[{
              {"1", "0", "0"},
              {"0", \(xu[r]\^2\), "0"},
              {"0", "0", \(\((xu[r] Sin[xu[\[Theta]]])\)\^2\)}
              }], ")"}]}], ";"}], "\[IndentingNewLine]", \(SetMetricValues[g, 
      metric]\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[{
    \(gdd[i, j] dxu[i] dxu[j]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\(% // UseCoordinates[]\) // 
      UseCoordinates[{dr, d\[Theta], d\[Phi]}, dx]\)}], "Input",
  CellLabel->"In[20]:="],

Cell["The invariant interval in special relativity", "Text"],

Cell[BoxData[{
    \(DeclareBaseIndices[{0, 1, 2, 3}]\), "\n", 
    \(\(metric = 
        DiagonalMatrix[{1, \(-1\), \(-1\), \(-1\)}];\)\), \
"\[IndentingNewLine]", 
    \(SetMetricValues[\[Eta], metric]\)}], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[{
    \(\[Eta]dd[i, j] dxu[i] dxu[j]\), "\[IndentingNewLine]", 
    \(% // EinsteinSum[]\), "\[IndentingNewLine]", 
    \(d\[Tau]\^2 == % // UseCoordinates[{dt, dx, dy, dz}, dx]\)}], "Input",
  CellLabel->"In[26]:="],

Cell["Restore settings", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, y, dx}, 1}, {{g, \[Eta]}, 2}]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[{
    \(DeclareBaseIndices[oldindices]\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors]\)}], "Input",
  CellLabel->"In[30]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 61, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1840, 56, 1297, 46, 89, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 8010, 258}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 61, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1840, 56, 1297, 46, 89, "Usage",
  CellTags->"Function?"],
Cell[3140, 104, 227, 4, 48, "MathCaption"],
Cell[3370, 110, 145, 3, 31, "MathCaption"],
Cell[3518, 115, 280, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3823, 129, 34, 0, 40, "ExampleSection"],
Cell[3860, 131, 96, 2, 29, "Input"],
Cell[3959, 135, 29, 0, 25, "Text"],
Cell[3991, 137, 357, 7, 109, "Input"],
Cell[4351, 146, 113, 2, 29, "Input"],
Cell[4467, 150, 107, 3, 25, "Text"],
Cell[4577, 155, 182, 4, 69, "Input"],
Cell[4762, 161, 131, 3, 25, "Text"],
Cell[4896, 166, 208, 4, 69, "Input"],
Cell[5107, 172, 99, 2, 25, "Text"],
Cell[5209, 176, 202, 4, 69, "Input"],
Cell[5414, 182, 176, 6, 25, "Text"],
Cell[5593, 190, 407, 9, 110, "Input"],
Cell[6003, 201, 249, 5, 69, "Input"],
Cell[6255, 208, 60, 0, 25, "Text"],
Cell[6318, 210, 242, 6, 69, "Input"],
Cell[6563, 218, 229, 4, 69, "Input"],
Cell[6795, 224, 32, 0, 25, "Text"],
Cell[6830, 226, 113, 2, 29, "Input"],
Cell[6946, 230, 295, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

