(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5559,        189]*)
(*NotebookOutlinePosition[      6566,        224]*)
(*  CellTagsIndexPosition[      6492,        218]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["UseTotalDChainRule", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"Use", 
              StyleBox["TotalDChainRule",
                "MR"]}]], 
          StyleBox["[",
            "MR"], 
          StyleBox[\(coordtensor, labels\),
            "TI"], 
          StyleBox["]",
            "MR"]}], 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  " expands total derivatives over coordtensor using the chain rule. The \
tensor labels are used in the generated partial derivative."
}], "Usage",
  CellTags->"Function?"],

Cell["The command works only of first order total derivatives.", "MathCaption"],

Cell[TextData[{
  "See also: ",
  ButtonBox["TotalD",
    ButtonData:>{"TotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ExpandTotalD",
    ButtonData:>{"ExpandTotalD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["UsePartialDChainRule",
    ButtonData:>{"UsePartialDChainRule"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples", "ExampleSection"],

Cell[BoxData[
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\)], "Input",
  CellLabel->"In[1]:="],

Cell["Save settings.", "Text"],

Cell[BoxData[{
    \(\(oldindices = BaseIndices;\)\), "\[IndentingNewLine]", 
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[2]:="],

Cell["Define the tensor shortcuts and derivative labels.", "Text"],

Cell[BoxData[{
    \(DefineTensorShortcuts[{{x, T}, 1}, {{S}, 2}]\), "\[IndentingNewLine]", 
    \(\(labs = {x, \[Delta], g, \[CapitalGamma]};\)\)}], "Input",
  CellLabel->"In[6]:="],

Cell["\<\
Here a total derivative is expanded using the chain rule with respect to a \
flavored coordinate system.\
\>", "Text"],

Cell[BoxData[{
    \(Tu[i]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\), "\[IndentingNewLine]", 
    \(% // UseTotalDChainRule[xu[red@a], labs]\)}], "Input",
  CellLabel->"In[8]:="],

Cell[TextData[{
  "The command works on all first order total derivatives in the expression. \
Use ",
  Cell[BoxData[
      \(MapAt\)]],
  " to restrict to specific parts of an expression."
}], "Text"],

Cell[BoxData[{
    \(Tu[i] Sdd[i, j]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\), "\[IndentingNewLine]", 
    \(% // UseTotalDChainRule[xu[red@a], labs]\)}], "Input",
  CellLabel->"In[11]:="],

Cell[TextData[{
  "Using the chain rule with the same flavor and coordinate is the same as \
using ",
  Cell[BoxData[
      \(ExpandTotalD\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(Tu[i] Sdd[i, j]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\), "\[IndentingNewLine]", 
    \(% // UseTotalDChainRule[xu[a], labs]\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Delta]]\)}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[{
    \(Tu[i] Sdd[i, j]\), "\[IndentingNewLine]", 
    \(TotalD[%, t]\), "\[IndentingNewLine]", 
    \(% // ExpandTotalD[labs, a]\)}], "Input",
  CellLabel->"In[18]:="],

Cell["Restore settings.", "Text"],

Cell[BoxData[
    \(ClearTensorShortcuts[{{x, T}, 1}, {{S}, 2}]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[{
    \(\(DeclareBaseIndices[oldindices];\)\), "\[IndentingNewLine]", 
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor[oldflavors];\)\), "\[IndentingNewLine]", 
    \(Clear[oldindices, oldflavors, labs]\)}], "Input",
  CellLabel->"In[22]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 943}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{665, 474},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 65, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1844, 56, 661, 24, 49, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 6321, 209}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 65, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1844, 56, 661, 24, 49, "Usage",
  CellTags->"Function?"],
Cell[2508, 82, 79, 0, 31, "MathCaption"],
Cell[2590, 84, 452, 18, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3067, 106, 34, 0, 40, "ExampleSection"],
Cell[3104, 108, 96, 2, 29, "Input"],
Cell[3203, 112, 30, 0, 25, "Text"],
Cell[3236, 114, 268, 5, 89, "Input"],
Cell[3507, 121, 66, 0, 25, "Text"],
Cell[3576, 123, 182, 3, 49, "Input"],
Cell[3761, 128, 128, 3, 25, "Text"],
Cell[3892, 133, 184, 4, 69, "Input"],
Cell[4079, 139, 201, 6, 25, "Text"],
Cell[4283, 147, 195, 4, 69, "Input"],
Cell[4481, 153, 161, 6, 25, "Text"],
Cell[4645, 161, 255, 5, 89, "Input"],
Cell[4903, 168, 181, 4, 69, "Input"],
Cell[5087, 174, 33, 0, 25, "Text"],
Cell[5123, 176, 101, 2, 29, "Input"],
Cell[5227, 180, 304, 5, 89, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

